package org.eclipse.soda.dk.gps.nmea.device;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import org.eclipse.soda.dk.device.TransportDevice;
import org.eclipse.soda.dk.device.service.DeviceService;
import org.eclipse.soda.dk.gps.nmea.device.messages.GpsNmeaDeviceMessages;
import org.eclipse.soda.dk.gps.nmea.device.service.GpsNmeaDeviceService;
import org.eclipse.soda.dk.gps.nmea.transport.service.GpsNmeaTransportService;
import org.eclipse.soda.dk.interest.InterestMask;
import org.eclipse.soda.dk.interest.service.InterestService;
import org.eclipse.soda.dk.measurement.SignalMeasurement;
import org.eclipse.soda.dk.measurement.service.MeasurementService;
import org.eclipse.soda.dk.message.Messages;
import org.eclipse.soda.dk.message.service.MessageService;
import org.eclipse.soda.dk.parameter.FieldParameter;
import org.eclipse.soda.dk.parameter.service.ParameterService;
import org.eclipse.soda.dk.signal.DataSignal;
import org.eclipse.soda.dk.signal.ParameterSignal;
import org.eclipse.soda.dk.signal.service.SignalService;
import org.eclipse.soda.dk.transport.service.TransportService;

/**
 * Global Positioning System (GPS) National Marine Electronics Association (NMEA) Device.
 * 
 * The GpsNmeaDevice class implements the GpsNmeaDeviceService and provides the controls for the device.
 * <p>The list of exported services:
 * @see org.eclipse.soda.dk.gps.nmea.device.service.GpsNmeaDeviceService
 * @see org.eclipse.soda.dk.device.service.DeviceService
 *  
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class GpsNmeaDevice extends TransportDevice implements DeviceService, GpsNmeaDeviceService {
	/**
	 * Defines the full class name.
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String CLASS_NAME = "org.eclipse.soda.dk.gps.nmea.device.GpsNmeaDevice"; //$NON-NLS-1$

	/**
	 * The interest filter for the device.
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final InterestService interest = new InterestMask(new byte[] { 0x24, 0x47, 0x50, 0x42, 0x44, 0x40 }, new byte[] { -1, -1, -1, (byte) 0xe2, (byte) 0xe4, (byte) 0xf0 });

	/**
	 * Defines the GPGLL signal <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Position</li>
	 * <li>Latitude</li>
	 * <li>Longitude</li>
	 * <li>Time</li>
	 * <li>Status</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final DataSignal gPGLL = new DataSignal(GpsNmeaDeviceService.GPGLL, GpsNmeaDeviceMessages.getGPGLLMessage());

	/**
	 * Defines the GPRMC signal <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Time</li>
	 * <li>Status</li>
	 * <li>Position</li>
	 * <li>Latitude</li>
	 * <li>Longitude</li>
	 * <li>SpeedKnots</li>
	 * <li>Track</li>
	 * <li>Date</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final DataSignal gPRMC = new DataSignal(GpsNmeaDeviceService.GPRMC, GpsNmeaDeviceMessages.getGPRMCMessage());

	/**
	 * Defines the GPGGA signal <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Time</li>
	 * <li>Position</li>
	 * <li>Latitude</li>
	 * <li>Longitude</li>
	 * <li>Quality</li>
	 * <li>NumberSatellites</li>
	 * <li>HorizontalDilutionOfPrecision</li>
	 * <li>Altitude</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final DataSignal gPGGA = new DataSignal(GpsNmeaDeviceService.GPGGA, GpsNmeaDeviceMessages.getGPGGAMessage());

	/**
	 * Defines the GPVTG signal <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Track</li>
	 * <li>TrackMagnetic</li>
	 * <li>SpeedKnots</li>
	 * <li>SpeedKPH</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final DataSignal gPVTG = new DataSignal(GpsNmeaDeviceService.GPVTG, GpsNmeaDeviceMessages.getGPVTGMessage());

	/**
	 * Defines the GPZDA signal <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Time</li>
	 * <li>Day</li>
	 * <li>Month</li>
	 * <li>Year</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final DataSignal gPZDA = new DataSignal(GpsNmeaDeviceService.GPZDA, GpsNmeaDeviceMessages.getGPZDAMessage());

	/**
	 * Defines the TimeReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Time</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final ParameterSignal timeReport = new ParameterSignal(GpsNmeaDeviceService.TimeReport, new Messages(new MessageService[] { GpsNmeaDeviceMessages.getGPRMCMessage(), GpsNmeaDeviceMessages.getGPGGAMessage() }), null, new FieldParameter(
			GpsNmeaDeviceService.Time, null, "Time", //$NON-NLS-1$
			ParameterService.NSTRING));

	/**
	 * Defines the Time measurement.
	 * <p>
	 * <ul>
	 * <li><b>Time</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final SignalMeasurement time = new SignalMeasurement( //
			GpsNmeaDeviceService.Time, //Key
			new java.util.HashMap(), //Value
			null, //Units
			null, //Transform
			this.timeReport);

	/**
	 * Defines the StatusReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Status</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final ParameterSignal statusReport = new ParameterSignal(GpsNmeaDeviceService.StatusReport, GpsNmeaDeviceMessages.getGPRMCMessage(), null, new FieldParameter(GpsNmeaDeviceService.Status, null, "Status")); //$NON-NLS-1$

	/**
	 * Defines the Status measurement.
	 * <p>
	 * <ul>
	 * <li><b>Status</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final SignalMeasurement status = new SignalMeasurement( //
			GpsNmeaDeviceService.Status, //Key
			new java.util.HashMap(), //Value
			null, //Units
			null, //Transform
			this.statusReport);

	/**
	 * Defines the LatitudeReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Latitude</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final ParameterSignal latitudeReport = new ParameterSignal(GpsNmeaDeviceService.LatitudeReport, new Messages(new MessageService[] { GpsNmeaDeviceMessages.getGPRMCMessage(), GpsNmeaDeviceMessages.getGPGGAMessage(),
			GpsNmeaDeviceMessages.getGPGLLMessage() }), null, new FieldParameter(GpsNmeaDeviceService.Latitude, null, "Latitude")); //$NON-NLS-1$

	/**
	 * Defines the PositionReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Position</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final ParameterSignal positionReport = new ParameterSignal(GpsNmeaDeviceService.PositionReport, new Messages(new MessageService[] { GpsNmeaDeviceMessages.getGPRMCMessage(), GpsNmeaDeviceMessages.getGPGGAMessage(),
			GpsNmeaDeviceMessages.getGPGLLMessage() }), null, new FieldParameter(GpsNmeaDeviceService.Position, null, "Position")); //$NON-NLS-1$

	/**
	 * Defines the Position measurement.
	 * <p>
	 * <ul>
	 * <li><b>Position</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final SignalMeasurement position = new SignalMeasurement( //
			GpsNmeaDeviceService.Position, //Key
			new java.util.HashMap(), //Value
			null, //Units
			null, //Transform
			this.positionReport);

	/**
	 * Defines the Latitude measurement.
	 * <p>
	 * <ul>
	 * <li><b>Latitude</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final SignalMeasurement latitude = new SignalMeasurement( //
			GpsNmeaDeviceService.Latitude, //Key
			new java.util.HashMap(), //Value
			null, //Units
			null, //Transform
			this.latitudeReport);

	/**
	 * Defines the LongitudeReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Longitude</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final ParameterSignal longitudeReport = new ParameterSignal(GpsNmeaDeviceService.LongitudeReport, new Messages(new MessageService[] { GpsNmeaDeviceMessages.getGPRMCMessage(), GpsNmeaDeviceMessages.getGPGGAMessage(),
			GpsNmeaDeviceMessages.getGPGLLMessage() }), null, new FieldParameter(GpsNmeaDeviceService.Longitude, null, "Longitude")); //$NON-NLS-1$

	/**
	 * Defines the Longitude measurement.
	 * <p>
	 * <ul>
	 * <li><b>Longitude</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final SignalMeasurement longitude = new SignalMeasurement( //
			GpsNmeaDeviceService.Longitude, //Key
			new java.util.HashMap(), //Value
			null, //Units
			null, //Transform
			this.longitudeReport);

	/**
	 * Defines the SpeedKnotsReport signal.
	 * <p>
	 * <ul>
	 * <li><b>SpeedKnots</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final ParameterSignal speedKnotsReport = new ParameterSignal(GpsNmeaDeviceService.SpeedKnotsReport, new Messages(new MessageService[] { GpsNmeaDeviceMessages.getGPRMCMessage(), GpsNmeaDeviceMessages.getGPVTGMessage() }), null,
			new FieldParameter(GpsNmeaDeviceService.SpeedKnots, null, "SpeedKnots", //$NON-NLS-1$
					ParameterService.NSTRING));

	/**
	 * Defines the SpeedKnots measurement.
	 * <p>
	 * <ul>
	 * <li><b>SpeedKnots</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final SignalMeasurement speedKnots = new SignalMeasurement( //
			GpsNmeaDeviceService.SpeedKnots, //Key
			new java.util.HashMap(), //Value
			null, //Units
			null, //Transform
			this.speedKnotsReport);

	/**
	 * Defines the SpeedKPHReport signal.
	 * <p>
	 * <ul>
	 * <li><b>SpeedKPH</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final ParameterSignal speedKPHReport = new ParameterSignal(GpsNmeaDeviceService.SpeedKPHReport, GpsNmeaDeviceMessages.getGPVTGMessage(), null, new FieldParameter(GpsNmeaDeviceService.SpeedKPH, null, "SpeedKPH", //$NON-NLS-1$
			ParameterService.NSTRING));

	/**
	 * Defines the SpeedKPH measurement.
	 * <p>
	 * <ul>
	 * <li><b>SpeedKPH</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final SignalMeasurement speedKPH = new SignalMeasurement( //
			GpsNmeaDeviceService.SpeedKPH, //Key
			new java.util.HashMap(), //Value
			null, //Units
			null, //Transform
			this.speedKPHReport);

	/**
	 * Defines the TrackReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Track</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final ParameterSignal trackReport = new ParameterSignal(GpsNmeaDeviceService.TrackReport, new Messages(new MessageService[] { GpsNmeaDeviceMessages.getGPRMCMessage(), GpsNmeaDeviceMessages.getGPVTGMessage() }), null, new FieldParameter(
			GpsNmeaDeviceService.Track, null, "Track", //$NON-NLS-1$
			ParameterService.NSTRING));

	/**
	 * Defines the Track measurement.
	 * <p>
	 * <ul>
	 * <li><b>Track</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final SignalMeasurement track = new SignalMeasurement( //
			GpsNmeaDeviceService.Track, //Key
			new java.util.HashMap(), //Value
			null, //Units
			null, //Transform
			this.trackReport);

	/**
	 * Defines the TrackMagneticReport signal.
	 * <p>
	 * <ul>
	 * <li><b>TrackMagnetic</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final ParameterSignal trackMagneticReport = new ParameterSignal(GpsNmeaDeviceService.TrackMagneticReport, GpsNmeaDeviceMessages.getGPVTGMessage(), null, new FieldParameter(GpsNmeaDeviceService.TrackMagnetic, null, "TrackMagnetic", //$NON-NLS-1$
			ParameterService.NSTRING));

	/**
	 * Defines the TrackMagnetic measurement.
	 * <p>
	 * <ul>
	 * <li><b>TrackMagnetic</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final SignalMeasurement trackMagnetic = new SignalMeasurement( //
			GpsNmeaDeviceService.TrackMagnetic, //Key
			new java.util.HashMap(), //Value
			null, //Units
			null, //Transform
			this.trackMagneticReport);

	/**
	 * Defines the AltitudeReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Altitude</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final ParameterSignal altitudeReport = new ParameterSignal(GpsNmeaDeviceService.AltitudeReport, GpsNmeaDeviceMessages.getGPGGAMessage(), null, new FieldParameter(GpsNmeaDeviceService.Altitude, null, "Altitude")); //$NON-NLS-1$

	/**
	 * Defines the Altitude measurement.
	 * <p>
	 * <ul>
	 * <li><b>Altitude</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final SignalMeasurement altitude = new SignalMeasurement( //
			GpsNmeaDeviceService.Altitude, //Key
			new java.util.HashMap(), //Value
			null, //Units
			null, //Transform
			this.altitudeReport);

	/**
	 * Defines the QualityReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Quality</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final ParameterSignal qualityReport = new ParameterSignal(GpsNmeaDeviceService.QualityReport, GpsNmeaDeviceMessages.getGPGGAMessage(), null, new FieldParameter(GpsNmeaDeviceService.Quality, null, "Quality")); //$NON-NLS-1$

	/**
	 * Defines the Quality measurement.
	 * <p>
	 * <ul>
	 * <li><b>Quality</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final SignalMeasurement quality = new SignalMeasurement( //
			GpsNmeaDeviceService.Quality, //Key
			new java.util.HashMap(), //Value
			null, //Units
			null, //Transform
			this.qualityReport);

	/**
	 * Defines the NumberSatellitesReport signal.
	 * <p>
	 * <ul>
	 * <li><b>NumberSatellites</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final ParameterSignal numberSatellitesReport = new ParameterSignal(GpsNmeaDeviceService.NumberSatellitesReport, GpsNmeaDeviceMessages.getGPGGAMessage(), null, new FieldParameter(GpsNmeaDeviceService.NumberSatellites, null, "NumberSatellites")); //$NON-NLS-1$

	/**
	 * Defines the NumberSatellites measurement.
	 * <p>
	 * <ul>
	 * <li><b>NumberSatellites</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final SignalMeasurement numberSatellites = new SignalMeasurement( //
			GpsNmeaDeviceService.NumberSatellites, //Key
			new java.util.HashMap(), //Value
			null, //Units
			null, //Transform
			this.numberSatellitesReport);

	/**
	 * Defines the DateReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Date</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final ParameterSignal dateReport = new ParameterSignal(GpsNmeaDeviceService.DateReport, GpsNmeaDeviceMessages.getGPRMCMessage(), null, new FieldParameter(GpsNmeaDeviceService.Date, null, "Date")); //$NON-NLS-1$

	/**
	 * The Date measurement contains a string in ddmmyy format.
	 * <p>
	 * <ul>
	 * <li><b>Date</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final SignalMeasurement date = new SignalMeasurement( //
			GpsNmeaDeviceService.Date, //Key
			new java.util.HashMap(), //Value
			null, //Units
			null, //Transform
			this.dateReport);

	/**
	 * Defines the HorizontalDilutionOfPrecisionReport signal.
	 * <p>
	 * <ul>
	 * <li><b>HorizontalDilutionOfPrecision</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final ParameterSignal horizontalDilutionOfPrecisionReport = new ParameterSignal(GpsNmeaDeviceService.HorizontalDilutionOfPrecisionReport, GpsNmeaDeviceMessages.getGPGGAMessage(), null, new FieldParameter(
			GpsNmeaDeviceService.HorizontalDilutionOfPrecision, null, "HorizontalDilutionOfPrecision")); //$NON-NLS-1$

	/**
	 * Defines the HorizontalDilutionOfPrecision measurement.
	 * <p>
	 * <ul>
	 * <li><b>HorizontalDilutionOfPrecision</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	private final SignalMeasurement horizontalDilutionOfPrecision = new SignalMeasurement( //
			GpsNmeaDeviceService.HorizontalDilutionOfPrecision, //Key
			new java.util.HashMap(), //Value
			null, //Units
			null, //Transform
			this.horizontalDilutionOfPrecisionReport);

	/**
	 * Constructs a new instance of the GpsNmeaDevice class.
	 * @since 1.0
	 */
	public GpsNmeaDevice() {
		/* Generated method and should not be changed. */
		super(GpsNmeaDeviceService.Capabilities, //Define the Capabilities Measurement
				GpsNmeaDeviceService.Status, //Define the Status Measurement
				GpsNmeaDeviceService.Configuration, //Define the Configuration Measurement
				GpsNmeaDeviceService.Metrics); //Define the Metrics Measurement
		setKey(getDefaultKey()); //The super class defines the common measurements
		initialize();
	}

	/**
	 * Gets the interest filter for the device.
	 * @return InterestService The interest filter for this device.
	 * @since 1.0
	 */
	public InterestService getInterest() {
		/* Generated method and should not be changed. */
		return this.interest;
	}

	/**
	 * Gets the default key of the device.
	 * @return String The default key
	 * @since 1.0
	 */
	public String getDefaultKey() {
		/* Generated method and should not be changed. */
		return GpsNmeaDeviceService.GpsNmeaDevice;
	}

	/**
	 * Gets the default TransportService.
	 * @return TransportService The default TransportService.
	 * @since 1.0
	 */
	public TransportService getDefaultTransport() {
		/* Generated method and should not be changed. */
		return (GpsNmeaTransportService) loadService(TransportService.SERVICE_NAME, "org.eclipse.soda.dk.gps.nmea.transport.GpsNmeaTransport"); //$NON-NLS-1$
	}

	/**
	 * Gets the control capacity.
	 * @return The control capacity value.
	 * @since 1.0
	 */
	public int getControlCapacity() {
		/* Generated method and should not be changed. */
		return 47;
	}

	/**
	 * Gets the message capacity.
	 * 
	 * @return int The message capacity.
	 * @since 1.0
	 */
	public int getMessageCapacity() {
		/* Generated method and should not be changed. */
		return 41;
	}

	/**
	 * Gets the message key.
	 * 
	 * @param message The message service.
	 * @return Object The message key.
	 * @since 1.0
	 */
	public Object getMessageKey(final MessageService message) {
		/* Generated method and should not be changed. */
		final byte[] bytes = message.getBytes();
		if ((bytes.length >= 6) && ((bytes[5] & 0xf0) == 0x40) && ((bytes[4] & 0xe4) == 0x44) && ((bytes[3] & 0xe2) == 0x42) && (bytes[2] == 0x50) && (bytes[1] == 0x47) && (bytes[0] == 0x24)) {
			return createInteger((bytes[3] & 0x1d) ^ ((bytes[4] & 0x1b) << 5) ^ ((bytes[5] & 0xf) << 10));
		}
		return null; //Not looking for this message.
	}

	/**
	 * Create and initialize the controls for this device.
	 * @since 1.0
	 */
	private void initialize() {
		/* Generated method and should not be changed. */
		final SignalService gPGLL = this.gPGLL; //Force reference to service class
		put(gPGLL);
		final SignalService gPRMC = this.gPRMC; //Force reference to service class
		put(gPRMC);
		final SignalService gPGGA = this.gPGGA; //Force reference to service class
		put(gPGGA);
		final SignalService gPVTG = this.gPVTG; //Force reference to service class
		put(gPVTG);
		final SignalService gPZDA = this.gPZDA; //Force reference to service class
		put(gPZDA);
		final SignalService timeReport = this.timeReport; //Force reference to service class
		put(timeReport);
		final MeasurementService time = this.time; //Force reference to service class
		put(time);
		final SignalService statusReport = this.statusReport; //Force reference to service class
		put(statusReport);
		final MeasurementService status = this.status; //Force reference to service class
		put(status);
		final SignalService latitudeReport = this.latitudeReport; //Force reference to service class
		put(latitudeReport);
		final SignalService positionReport = this.positionReport; //Force reference to service class
		put(positionReport);
		final MeasurementService position = this.position; //Force reference to service class
		put(position);
		final MeasurementService latitude = this.latitude; //Force reference to service class
		put(latitude);
		final SignalService longitudeReport = this.longitudeReport; //Force reference to service class
		put(longitudeReport);
		final MeasurementService longitude = this.longitude; //Force reference to service class
		put(longitude);
		final SignalService speedKnotsReport = this.speedKnotsReport; //Force reference to service class
		put(speedKnotsReport);
		final MeasurementService speedKnots = this.speedKnots; //Force reference to service class
		put(speedKnots);
		final SignalService speedKPHReport = this.speedKPHReport; //Force reference to service class
		put(speedKPHReport);
		final MeasurementService speedKPH = this.speedKPH; //Force reference to service class
		put(speedKPH);
		final SignalService trackReport = this.trackReport; //Force reference to service class
		put(trackReport);
		final MeasurementService track = this.track; //Force reference to service class
		put(track);
		final SignalService trackMagneticReport = this.trackMagneticReport; //Force reference to service class
		put(trackMagneticReport);
		final MeasurementService trackMagnetic = this.trackMagnetic; //Force reference to service class
		put(trackMagnetic);
		final SignalService altitudeReport = this.altitudeReport; //Force reference to service class
		put(altitudeReport);
		final MeasurementService altitude = this.altitude; //Force reference to service class
		put(altitude);
		final SignalService qualityReport = this.qualityReport; //Force reference to service class
		put(qualityReport);
		final MeasurementService quality = this.quality; //Force reference to service class
		put(quality);
		final SignalService numberSatellitesReport = this.numberSatellitesReport; //Force reference to service class
		put(numberSatellitesReport);
		final MeasurementService numberSatellites = this.numberSatellites; //Force reference to service class
		put(numberSatellites);
		final SignalService dateReport = this.dateReport; //Force reference to service class
		put(dateReport);
		final MeasurementService date = this.date; //Force reference to service class
		put(date);
		final SignalService horizontalDilutionOfPrecisionReport = this.horizontalDilutionOfPrecisionReport; //Force reference to service class
		put(horizontalDilutionOfPrecisionReport);
		final MeasurementService horizontalDilutionOfPrecision = this.horizontalDilutionOfPrecision; //Force reference to service class
		put(horizontalDilutionOfPrecision);
	}

	/**
	 * @see org.eclipse.soda.dk.device.Container#setup()
	 * @since 1.2
	 */
	public void setup() {
		/* Generated method and should not be changed. */
		super.setup();
		setNotificationPriority(getInt("gpsnmeadevice.notificationpriority", getNotificationPriority())); //$NON-NLS-1$
	}
}
