package org.eclipse.soda.dk.gps.nmea.device.service;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import org.eclipse.soda.dk.device.service.DeviceService;
import org.eclipse.soda.dk.notification.service.NotificationService;

/**
 * Global Positioning System (GPS) National Marine Electronics Association (NMEA) Device.
 * 
 *  The device service interface defines the service to be registered for the GpsNmeaDevice device. 
 * <p>The following measurements are supported:
 *  
 * <table width=100%>
 * 	<tr>
 * 		<td width=40%><a href="#Time">Time</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#Status">Status</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#Position">Position</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#Latitude">Latitude</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#Longitude">Longitude</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#SpeedKnots">SpeedKnots</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#SpeedKPH">SpeedKPH</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#Track">Track</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#TrackMagnetic">TrackMagnetic</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#Altitude">Altitude</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#Quality">Quality</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#NumberSatellites">NumberSatellites</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#Date">Date</a></td>
 * 		<td width=60%>The Date measurement contains a string in ddmmyy format.</td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#HorizontalDilutionOfPrecision">HorizontalDilutionOfPrecision</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * </table>
 *  
 * <p>The following signals are supported:
 *  
 * <table width=100%>
 * 	<tr>
 * 		<td width=40%><a href="#GPGLL">GPGLL</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#GPRMC">GPRMC</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#GPGGA">GPGGA</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#GPVTG">GPVTG</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#GPZDA">GPZDA</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#TimeReport">TimeReport</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#StatusReport">StatusReport</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#LatitudeReport">LatitudeReport</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#PositionReport">PositionReport</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#LongitudeReport">LongitudeReport</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#SpeedKnotsReport">SpeedKnotsReport</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#SpeedKPHReport">SpeedKPHReport</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#TrackReport">TrackReport</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#TrackMagneticReport">TrackMagneticReport</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#AltitudeReport">AltitudeReport</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#QualityReport">QualityReport</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#NumberSatellitesReport">NumberSatellitesReport</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#DateReport">DateReport</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * 	<tr>
 * 		<td width=40%><a href="#HorizontalDilutionOfPrecisionReport">HorizontalDilutionOfPrecisionReport</a></td>
 * 		<td width=60%></td>
 * 	</tr>
 * </table>
 *  
 *  
 * <p>The list of exported services:
 * @see org.eclipse.soda.dk.gps.nmea.device.service.GpsNmeaDeviceService
 * @see org.eclipse.soda.dk.device.service.DeviceService
 *  
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public interface GpsNmeaDeviceService extends DeviceService {
	/**
	 * Define the OSGi service name.
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String SERVICE_NAME = "org.eclipse.soda.dk.gps.nmea.device.service.GpsNmeaDeviceService"; //$NON-NLS-1$

	/**
	 * Define the OSGi managed service name.
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String MANAGED_SERVICE_NAME = "org.eclipse.soda.dk.gps.nmea.device.managed.GpsNmeaDeviceManaged"; //$NON-NLS-1$

	/**
	 * Define the OSGi factory service name.
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String FACTORY_SERVICE_NAME = "org.eclipse.soda.dk.gps.nmea.device.factory.GpsNmeaDeviceFactory"; //$NON-NLS-1$

	/**
	 * Define the GpsNmeaDevice key.
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String GpsNmeaDevice = "GpsNmeaDevice"; //$NON-NLS-1$

	/**
	 * Defines the GPGLL signal <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Position</li>
	 * <li>Latitude</li>
	 * <li>Longitude</li>
	 * <li>Time</li>
	 * <li>Status</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String GPGLL = "GPGLL"; //$NON-NLS-1$

	/**
	 * Defines the GPGLL signal <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Position</li>
	 * <li>Latitude</li>
	 * <li>Longitude</li>
	 * <li>Time</li>
	 * <li>Status</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @see #GPGLL
	 * The value of this field is "<i>prefix/<i><b>GPGLL</b>"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String GPGLL_EXTERNAL_KEY = "GPGLL"; //$NON-NLS-1$

	/**
	 * Defines the GPGLL signal <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Position</li>
	 * <li>Latitude</li>
	 * <li>Longitude</li>
	 * <li>Time</li>
	 * <li>Status</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @see #GPGLL
	 * The value of this field is "<i>prefix/<i><b>GPGLL</b>/trigger"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String GPGLL_TRIGGER_EXTERNAL_KEY = GpsNmeaDeviceService.GPGLL_EXTERNAL_KEY + NotificationService.TRIGGER_EXTERNAL_KEY;

	/**
	 * Defines the GPGLL signal <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Position</li>
	 * <li>Latitude</li>
	 * <li>Longitude</li>
	 * <li>Time</li>
	 * <li>Status</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @see #GPGLL
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#TRIGGER_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>GPGLL</b>/error"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String GPGLL_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.GPGLL_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the GPRMC signal <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Time</li>
	 * <li>Status</li>
	 * <li>Position</li>
	 * <li>Latitude</li>
	 * <li>Longitude</li>
	 * <li>SpeedKnots</li>
	 * <li>Track</li>
	 * <li>Date</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String GPRMC = "GPRMC"; //$NON-NLS-1$

	/**
	 * Defines the GPRMC signal <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Time</li>
	 * <li>Status</li>
	 * <li>Position</li>
	 * <li>Latitude</li>
	 * <li>Longitude</li>
	 * <li>SpeedKnots</li>
	 * <li>Track</li>
	 * <li>Date</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @see #GPRMC
	 * The value of this field is "<i>prefix/<i><b>GPRMC</b>"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String GPRMC_EXTERNAL_KEY = "GPRMC"; //$NON-NLS-1$

	/**
	 * Defines the GPRMC signal <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Time</li>
	 * <li>Status</li>
	 * <li>Position</li>
	 * <li>Latitude</li>
	 * <li>Longitude</li>
	 * <li>SpeedKnots</li>
	 * <li>Track</li>
	 * <li>Date</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @see #GPRMC
	 * The value of this field is "<i>prefix/<i><b>GPRMC</b>/trigger"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String GPRMC_TRIGGER_EXTERNAL_KEY = GpsNmeaDeviceService.GPRMC_EXTERNAL_KEY + NotificationService.TRIGGER_EXTERNAL_KEY;

	/**
	 * Defines the GPRMC signal <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Time</li>
	 * <li>Status</li>
	 * <li>Position</li>
	 * <li>Latitude</li>
	 * <li>Longitude</li>
	 * <li>SpeedKnots</li>
	 * <li>Track</li>
	 * <li>Date</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @see #GPRMC
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#TRIGGER_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>GPRMC</b>/error"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String GPRMC_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.GPRMC_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the GPGGA signal <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Time</li>
	 * <li>Position</li>
	 * <li>Latitude</li>
	 * <li>Longitude</li>
	 * <li>Quality</li>
	 * <li>NumberSatellites</li>
	 * <li>HorizontalDilutionOfPrecision</li>
	 * <li>Altitude</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String GPGGA = "GPGGA"; //$NON-NLS-1$

	/**
	 * Defines the GPGGA signal <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Time</li>
	 * <li>Position</li>
	 * <li>Latitude</li>
	 * <li>Longitude</li>
	 * <li>Quality</li>
	 * <li>NumberSatellites</li>
	 * <li>HorizontalDilutionOfPrecision</li>
	 * <li>Altitude</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @see #GPGGA
	 * The value of this field is "<i>prefix/<i><b>GPGGA</b>"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String GPGGA_EXTERNAL_KEY = "GPGGA"; //$NON-NLS-1$

	/**
	 * Defines the GPGGA signal <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Time</li>
	 * <li>Position</li>
	 * <li>Latitude</li>
	 * <li>Longitude</li>
	 * <li>Quality</li>
	 * <li>NumberSatellites</li>
	 * <li>HorizontalDilutionOfPrecision</li>
	 * <li>Altitude</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @see #GPGGA
	 * The value of this field is "<i>prefix/<i><b>GPGGA</b>/trigger"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String GPGGA_TRIGGER_EXTERNAL_KEY = GpsNmeaDeviceService.GPGGA_EXTERNAL_KEY + NotificationService.TRIGGER_EXTERNAL_KEY;

	/**
	 * Defines the GPGGA signal <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Time</li>
	 * <li>Position</li>
	 * <li>Latitude</li>
	 * <li>Longitude</li>
	 * <li>Quality</li>
	 * <li>NumberSatellites</li>
	 * <li>HorizontalDilutionOfPrecision</li>
	 * <li>Altitude</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @see #GPGGA
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#TRIGGER_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>GPGGA</b>/error"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String GPGGA_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.GPGGA_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the GPVTG signal <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Track</li>
	 * <li>TrackMagnetic</li>
	 * <li>SpeedKnots</li>
	 * <li>SpeedKPH</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String GPVTG = "GPVTG"; //$NON-NLS-1$

	/**
	 * Defines the GPVTG signal <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Track</li>
	 * <li>TrackMagnetic</li>
	 * <li>SpeedKnots</li>
	 * <li>SpeedKPH</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @see #GPVTG
	 * The value of this field is "<i>prefix/<i><b>GPVTG</b>"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String GPVTG_EXTERNAL_KEY = "GPVTG"; //$NON-NLS-1$

	/**
	 * Defines the GPVTG signal <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Track</li>
	 * <li>TrackMagnetic</li>
	 * <li>SpeedKnots</li>
	 * <li>SpeedKPH</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @see #GPVTG
	 * The value of this field is "<i>prefix/<i><b>GPVTG</b>/trigger"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String GPVTG_TRIGGER_EXTERNAL_KEY = GpsNmeaDeviceService.GPVTG_EXTERNAL_KEY + NotificationService.TRIGGER_EXTERNAL_KEY;

	/**
	 * Defines the GPVTG signal <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Track</li>
	 * <li>TrackMagnetic</li>
	 * <li>SpeedKnots</li>
	 * <li>SpeedKPH</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @see #GPVTG
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#TRIGGER_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>GPVTG</b>/error"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String GPVTG_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.GPVTG_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the GPZDA signal <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Time</li>
	 * <li>Day</li>
	 * <li>Month</li>
	 * <li>Year</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String GPZDA = "GPZDA"; //$NON-NLS-1$

	/**
	 * Defines the GPZDA signal <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Time</li>
	 * <li>Day</li>
	 * <li>Month</li>
	 * <li>Year</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @see #GPZDA
	 * The value of this field is "<i>prefix/<i><b>GPZDA</b>"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String GPZDA_EXTERNAL_KEY = "GPZDA"; //$NON-NLS-1$

	/**
	 * Defines the GPZDA signal <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Time</li>
	 * <li>Day</li>
	 * <li>Month</li>
	 * <li>Year</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @see #GPZDA
	 * The value of this field is "<i>prefix/<i><b>GPZDA</b>/trigger"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String GPZDA_TRIGGER_EXTERNAL_KEY = GpsNmeaDeviceService.GPZDA_EXTERNAL_KEY + NotificationService.TRIGGER_EXTERNAL_KEY;

	/**
	 * Defines the GPZDA signal <code>Map</code>.
	 * <p>
	 * <ul>
	 * <li>parameters <code>Map</code></li>
	 * <ul>
	 * <li>Time</li>
	 * <li>Day</li>
	 * <li>Month</li>
	 * <li>Year</li>
	 * </ul>
	 * </ul>
	 * </p>
	 * @see #GPZDA
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#TRIGGER_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>GPZDA</b>/error"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String GPZDA_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.GPZDA_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the TimeReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Time</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String TimeReport = "TimeReport"; //$NON-NLS-1$

	/**
	 * Defines the TimeReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Time</b></li>
	 * </ul>
	 * </p>
	 * @see #TimeReport
	 * The value of this field is "<i>prefix/<i><b>TimeReport</b>"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String TIME_REPORT_EXTERNAL_KEY = "TimeReport"; //$NON-NLS-1$

	/**
	 * Defines the TimeReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Time</b></li>
	 * </ul>
	 * </p>
	 * @see #TimeReport
	 * The value of this field is "<i>prefix/<i><b>TimeReport</b>/trigger"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String TIME_REPORT_TRIGGER_EXTERNAL_KEY = GpsNmeaDeviceService.TIME_REPORT_EXTERNAL_KEY + NotificationService.TRIGGER_EXTERNAL_KEY;

	/**
	 * Defines the TimeReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Time</b></li>
	 * </ul>
	 * </p>
	 * @see #TimeReport
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#TRIGGER_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>TimeReport</b>/error"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String TIME_REPORT_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.TIME_REPORT_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the Time measurement.
	 * <p>
	 * <ul>
	 * <li><b>Time</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String Time = "Time"; //$NON-NLS-1$

	/**
	 * Defines the Time measurement.
	 * <p>
	 * <ul>
	 * <li><b>Time</b></li>
	 * </ul>
	 * </p>
	 * @see #Time
	 * The value of this field is "<i>prefix/<i><b>Time</b>"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String TIME_EXTERNAL_KEY = "Time"; //$NON-NLS-1$

	/**
	 * Defines the Time measurement.
	 * <p>
	 * <ul>
	 * <li><b>Time</b></li>
	 * </ul>
	 * </p>
	 * @see #Time
	 * The value of this field is "<i>prefix/<i><b>Time</b>/get"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String TIME_GET_EXTERNAL_KEY = GpsNmeaDeviceService.TIME_EXTERNAL_KEY + NotificationService.GET_EXTERNAL_KEY;

	/**
	 * Defines the Time measurement.
	 * <p>
	 * <ul>
	 * <li><b>Time</b></li>
	 * </ul>
	 * </p>
	 * @see #Time
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>Time</b>/read"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String TIME_READ_EXTERNAL_KEY = GpsNmeaDeviceService.TIME_EXTERNAL_KEY + NotificationService.READ_EXTERNAL_KEY;

	/**
	 * Defines the Time measurement.
	 * <p>
	 * <ul>
	 * <li><b>Time</b></li>
	 * </ul>
	 * </p>
	 * @see #Time
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#WRITE_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>Time</b>/write"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String TIME_WRITE_EXTERNAL_KEY = GpsNmeaDeviceService.TIME_EXTERNAL_KEY + NotificationService.WRITE_EXTERNAL_KEY;

	/**
	 * Defines the Time measurement.
	 * <p>
	 * <ul>
	 * <li><b>Time</b></li>
	 * </ul>
	 * </p>
	 * @see #Time
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#WRITE_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>Time</b>/error"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String TIME_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.TIME_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the StatusReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Status</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String StatusReport = "StatusReport"; //$NON-NLS-1$

	/**
	 * Defines the StatusReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Status</b></li>
	 * </ul>
	 * </p>
	 * @see #StatusReport
	 * The value of this field is "<i>prefix/<i><b>StatusReport</b>"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String STATUS_REPORT_EXTERNAL_KEY = "StatusReport"; //$NON-NLS-1$

	/**
	 * Defines the StatusReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Status</b></li>
	 * </ul>
	 * </p>
	 * @see #StatusReport
	 * The value of this field is "<i>prefix/<i><b>StatusReport</b>/trigger"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String STATUS_REPORT_TRIGGER_EXTERNAL_KEY = GpsNmeaDeviceService.STATUS_REPORT_EXTERNAL_KEY + NotificationService.TRIGGER_EXTERNAL_KEY;

	/**
	 * Defines the StatusReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Status</b></li>
	 * </ul>
	 * </p>
	 * @see #StatusReport
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#TRIGGER_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>StatusReport</b>/error"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String STATUS_REPORT_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.STATUS_REPORT_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the Status measurement.
	 * <p>
	 * <ul>
	 * <li><b>Status</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String Status = "Status"; //$NON-NLS-1$

	/**
	 * Defines the Status measurement.
	 * <p>
	 * <ul>
	 * <li><b>Status</b></li>
	 * </ul>
	 * </p>
	 * @see #Status
	 * The value of this field is "<i>prefix/<i><b>Status</b>"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String STATUS_EXTERNAL_KEY = "Status"; //$NON-NLS-1$

	/**
	 * Defines the Status measurement.
	 * <p>
	 * <ul>
	 * <li><b>Status</b></li>
	 * </ul>
	 * </p>
	 * @see #Status
	 * The value of this field is "<i>prefix/<i><b>Status</b>/get"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String STATUS_GET_EXTERNAL_KEY = GpsNmeaDeviceService.STATUS_EXTERNAL_KEY + NotificationService.GET_EXTERNAL_KEY;

	/**
	 * Defines the Status measurement.
	 * <p>
	 * <ul>
	 * <li><b>Status</b></li>
	 * </ul>
	 * </p>
	 * @see #Status
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>Status</b>/read"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String STATUS_READ_EXTERNAL_KEY = GpsNmeaDeviceService.STATUS_EXTERNAL_KEY + NotificationService.READ_EXTERNAL_KEY;

	/**
	 * Defines the Status measurement.
	 * <p>
	 * <ul>
	 * <li><b>Status</b></li>
	 * </ul>
	 * </p>
	 * @see #Status
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#WRITE_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>Status</b>/write"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String STATUS_WRITE_EXTERNAL_KEY = GpsNmeaDeviceService.STATUS_EXTERNAL_KEY + NotificationService.WRITE_EXTERNAL_KEY;

	/**
	 * Defines the Status measurement.
	 * <p>
	 * <ul>
	 * <li><b>Status</b></li>
	 * </ul>
	 * </p>
	 * @see #Status
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#WRITE_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>Status</b>/error"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String STATUS_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.STATUS_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the LatitudeReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Latitude</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String LatitudeReport = "LatitudeReport"; //$NON-NLS-1$

	/**
	 * Defines the LatitudeReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Latitude</b></li>
	 * </ul>
	 * </p>
	 * @see #LatitudeReport
	 * The value of this field is "<i>prefix/<i><b>LatitudeReport</b>"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String LATITUDE_REPORT_EXTERNAL_KEY = "LatitudeReport"; //$NON-NLS-1$

	/**
	 * Defines the LatitudeReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Latitude</b></li>
	 * </ul>
	 * </p>
	 * @see #LatitudeReport
	 * The value of this field is "<i>prefix/<i><b>LatitudeReport</b>/trigger"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String LATITUDE_REPORT_TRIGGER_EXTERNAL_KEY = GpsNmeaDeviceService.LATITUDE_REPORT_EXTERNAL_KEY + NotificationService.TRIGGER_EXTERNAL_KEY;

	/**
	 * Defines the LatitudeReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Latitude</b></li>
	 * </ul>
	 * </p>
	 * @see #LatitudeReport
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#TRIGGER_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>LatitudeReport</b>/error"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String LATITUDE_REPORT_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.LATITUDE_REPORT_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the PositionReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Position</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String PositionReport = "PositionReport"; //$NON-NLS-1$

	/**
	 * Defines the PositionReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Position</b></li>
	 * </ul>
	 * </p>
	 * @see #PositionReport
	 * The value of this field is "<i>prefix/<i><b>PositionReport</b>"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String POSITION_REPORT_EXTERNAL_KEY = "PositionReport"; //$NON-NLS-1$

	/**
	 * Defines the PositionReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Position</b></li>
	 * </ul>
	 * </p>
	 * @see #PositionReport
	 * The value of this field is "<i>prefix/<i><b>PositionReport</b>/trigger"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String POSITION_REPORT_TRIGGER_EXTERNAL_KEY = GpsNmeaDeviceService.POSITION_REPORT_EXTERNAL_KEY + NotificationService.TRIGGER_EXTERNAL_KEY;

	/**
	 * Defines the PositionReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Position</b></li>
	 * </ul>
	 * </p>
	 * @see #PositionReport
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#TRIGGER_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>PositionReport</b>/error"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String POSITION_REPORT_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.POSITION_REPORT_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the Position measurement.
	 * <p>
	 * <ul>
	 * <li><b>Position</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String Position = "Position"; //$NON-NLS-1$

	/**
	 * Defines the Position measurement.
	 * <p>
	 * <ul>
	 * <li><b>Position</b></li>
	 * </ul>
	 * </p>
	 * @see #Position
	 * The value of this field is "<i>prefix/<i><b>Position</b>"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String POSITION_EXTERNAL_KEY = "Position"; //$NON-NLS-1$

	/**
	 * Defines the Position measurement.
	 * <p>
	 * <ul>
	 * <li><b>Position</b></li>
	 * </ul>
	 * </p>
	 * @see #Position
	 * The value of this field is "<i>prefix/<i><b>Position</b>/get"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String POSITION_GET_EXTERNAL_KEY = GpsNmeaDeviceService.POSITION_EXTERNAL_KEY + NotificationService.GET_EXTERNAL_KEY;

	/**
	 * Defines the Position measurement.
	 * <p>
	 * <ul>
	 * <li><b>Position</b></li>
	 * </ul>
	 * </p>
	 * @see #Position
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>Position</b>/read"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String POSITION_READ_EXTERNAL_KEY = GpsNmeaDeviceService.POSITION_EXTERNAL_KEY + NotificationService.READ_EXTERNAL_KEY;

	/**
	 * Defines the Position measurement.
	 * <p>
	 * <ul>
	 * <li><b>Position</b></li>
	 * </ul>
	 * </p>
	 * @see #Position
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#WRITE_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>Position</b>/write"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String POSITION_WRITE_EXTERNAL_KEY = GpsNmeaDeviceService.POSITION_EXTERNAL_KEY + NotificationService.WRITE_EXTERNAL_KEY;

	/**
	 * Defines the Position measurement.
	 * <p>
	 * <ul>
	 * <li><b>Position</b></li>
	 * </ul>
	 * </p>
	 * @see #Position
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#WRITE_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>Position</b>/error"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String POSITION_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.POSITION_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the Latitude measurement.
	 * <p>
	 * <ul>
	 * <li><b>Latitude</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String Latitude = "Latitude"; //$NON-NLS-1$

	/**
	 * Defines the Latitude measurement.
	 * <p>
	 * <ul>
	 * <li><b>Latitude</b></li>
	 * </ul>
	 * </p>
	 * @see #Latitude
	 * The value of this field is "<i>prefix/<i><b>Latitude</b>"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String LATITUDE_EXTERNAL_KEY = "Latitude"; //$NON-NLS-1$

	/**
	 * Defines the Latitude measurement.
	 * <p>
	 * <ul>
	 * <li><b>Latitude</b></li>
	 * </ul>
	 * </p>
	 * @see #Latitude
	 * The value of this field is "<i>prefix/<i><b>Latitude</b>/get"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String LATITUDE_GET_EXTERNAL_KEY = GpsNmeaDeviceService.LATITUDE_EXTERNAL_KEY + NotificationService.GET_EXTERNAL_KEY;

	/**
	 * Defines the Latitude measurement.
	 * <p>
	 * <ul>
	 * <li><b>Latitude</b></li>
	 * </ul>
	 * </p>
	 * @see #Latitude
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>Latitude</b>/read"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String LATITUDE_READ_EXTERNAL_KEY = GpsNmeaDeviceService.LATITUDE_EXTERNAL_KEY + NotificationService.READ_EXTERNAL_KEY;

	/**
	 * Defines the Latitude measurement.
	 * <p>
	 * <ul>
	 * <li><b>Latitude</b></li>
	 * </ul>
	 * </p>
	 * @see #Latitude
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#WRITE_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>Latitude</b>/write"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String LATITUDE_WRITE_EXTERNAL_KEY = GpsNmeaDeviceService.LATITUDE_EXTERNAL_KEY + NotificationService.WRITE_EXTERNAL_KEY;

	/**
	 * Defines the Latitude measurement.
	 * <p>
	 * <ul>
	 * <li><b>Latitude</b></li>
	 * </ul>
	 * </p>
	 * @see #Latitude
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#WRITE_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>Latitude</b>/error"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String LATITUDE_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.LATITUDE_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the LongitudeReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Longitude</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String LongitudeReport = "LongitudeReport"; //$NON-NLS-1$

	/**
	 * Defines the LongitudeReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Longitude</b></li>
	 * </ul>
	 * </p>
	 * @see #LongitudeReport
	 * The value of this field is "<i>prefix/<i><b>LongitudeReport</b>"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String LONGITUDE_REPORT_EXTERNAL_KEY = "LongitudeReport"; //$NON-NLS-1$

	/**
	 * Defines the LongitudeReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Longitude</b></li>
	 * </ul>
	 * </p>
	 * @see #LongitudeReport
	 * The value of this field is "<i>prefix/<i><b>LongitudeReport</b>/trigger"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String LONGITUDE_REPORT_TRIGGER_EXTERNAL_KEY = GpsNmeaDeviceService.LONGITUDE_REPORT_EXTERNAL_KEY + NotificationService.TRIGGER_EXTERNAL_KEY;

	/**
	 * Defines the LongitudeReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Longitude</b></li>
	 * </ul>
	 * </p>
	 * @see #LongitudeReport
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#TRIGGER_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>LongitudeReport</b>/error"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String LONGITUDE_REPORT_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.LONGITUDE_REPORT_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the Longitude measurement.
	 * <p>
	 * <ul>
	 * <li><b>Longitude</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String Longitude = "Longitude"; //$NON-NLS-1$

	/**
	 * Defines the Longitude measurement.
	 * <p>
	 * <ul>
	 * <li><b>Longitude</b></li>
	 * </ul>
	 * </p>
	 * @see #Longitude
	 * The value of this field is "<i>prefix/<i><b>Longitude</b>"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String LONGITUDE_EXTERNAL_KEY = "Longitude"; //$NON-NLS-1$

	/**
	 * Defines the Longitude measurement.
	 * <p>
	 * <ul>
	 * <li><b>Longitude</b></li>
	 * </ul>
	 * </p>
	 * @see #Longitude
	 * The value of this field is "<i>prefix/<i><b>Longitude</b>/get"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String LONGITUDE_GET_EXTERNAL_KEY = GpsNmeaDeviceService.LONGITUDE_EXTERNAL_KEY + NotificationService.GET_EXTERNAL_KEY;

	/**
	 * Defines the Longitude measurement.
	 * <p>
	 * <ul>
	 * <li><b>Longitude</b></li>
	 * </ul>
	 * </p>
	 * @see #Longitude
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>Longitude</b>/read"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String LONGITUDE_READ_EXTERNAL_KEY = GpsNmeaDeviceService.LONGITUDE_EXTERNAL_KEY + NotificationService.READ_EXTERNAL_KEY;

	/**
	 * Defines the Longitude measurement.
	 * <p>
	 * <ul>
	 * <li><b>Longitude</b></li>
	 * </ul>
	 * </p>
	 * @see #Longitude
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#WRITE_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>Longitude</b>/write"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String LONGITUDE_WRITE_EXTERNAL_KEY = GpsNmeaDeviceService.LONGITUDE_EXTERNAL_KEY + NotificationService.WRITE_EXTERNAL_KEY;

	/**
	 * Defines the Longitude measurement.
	 * <p>
	 * <ul>
	 * <li><b>Longitude</b></li>
	 * </ul>
	 * </p>
	 * @see #Longitude
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#WRITE_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>Longitude</b>/error"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String LONGITUDE_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.LONGITUDE_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the SpeedKnotsReport signal.
	 * <p>
	 * <ul>
	 * <li><b>SpeedKnots</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String SpeedKnotsReport = "SpeedKnotsReport"; //$NON-NLS-1$

	/**
	 * Defines the SpeedKnotsReport signal.
	 * <p>
	 * <ul>
	 * <li><b>SpeedKnots</b></li>
	 * </ul>
	 * </p>
	 * @see #SpeedKnotsReport
	 * The value of this field is "<i>prefix/<i><b>SpeedKnotsReport</b>"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String SPEED_KNOTS_REPORT_EXTERNAL_KEY = "SpeedKnotsReport"; //$NON-NLS-1$

	/**
	 * Defines the SpeedKnotsReport signal.
	 * <p>
	 * <ul>
	 * <li><b>SpeedKnots</b></li>
	 * </ul>
	 * </p>
	 * @see #SpeedKnotsReport
	 * The value of this field is "<i>prefix/<i><b>SpeedKnotsReport</b>/trigger"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String SPEED_KNOTS_REPORT_TRIGGER_EXTERNAL_KEY = GpsNmeaDeviceService.SPEED_KNOTS_REPORT_EXTERNAL_KEY + NotificationService.TRIGGER_EXTERNAL_KEY;

	/**
	 * Defines the SpeedKnotsReport signal.
	 * <p>
	 * <ul>
	 * <li><b>SpeedKnots</b></li>
	 * </ul>
	 * </p>
	 * @see #SpeedKnotsReport
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#TRIGGER_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>SpeedKnotsReport</b>/error"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String SPEED_KNOTS_REPORT_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.SPEED_KNOTS_REPORT_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the SpeedKnots measurement.
	 * <p>
	 * <ul>
	 * <li><b>SpeedKnots</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String SpeedKnots = "SpeedKnots"; //$NON-NLS-1$

	/**
	 * Defines the SpeedKnots measurement.
	 * <p>
	 * <ul>
	 * <li><b>SpeedKnots</b></li>
	 * </ul>
	 * </p>
	 * @see #SpeedKnots
	 * The value of this field is "<i>prefix/<i><b>SpeedKnots</b>"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String SPEED_KNOTS_EXTERNAL_KEY = "SpeedKnots"; //$NON-NLS-1$

	/**
	 * Defines the SpeedKnots measurement.
	 * <p>
	 * <ul>
	 * <li><b>SpeedKnots</b></li>
	 * </ul>
	 * </p>
	 * @see #SpeedKnots
	 * The value of this field is "<i>prefix/<i><b>SpeedKnots</b>/get"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String SPEED_KNOTS_GET_EXTERNAL_KEY = GpsNmeaDeviceService.SPEED_KNOTS_EXTERNAL_KEY + NotificationService.GET_EXTERNAL_KEY;

	/**
	 * Defines the SpeedKnots measurement.
	 * <p>
	 * <ul>
	 * <li><b>SpeedKnots</b></li>
	 * </ul>
	 * </p>
	 * @see #SpeedKnots
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>SpeedKnots</b>/read"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String SPEED_KNOTS_READ_EXTERNAL_KEY = GpsNmeaDeviceService.SPEED_KNOTS_EXTERNAL_KEY + NotificationService.READ_EXTERNAL_KEY;

	/**
	 * Defines the SpeedKnots measurement.
	 * <p>
	 * <ul>
	 * <li><b>SpeedKnots</b></li>
	 * </ul>
	 * </p>
	 * @see #SpeedKnots
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#WRITE_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>SpeedKnots</b>/write"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String SPEED_KNOTS_WRITE_EXTERNAL_KEY = GpsNmeaDeviceService.SPEED_KNOTS_EXTERNAL_KEY + NotificationService.WRITE_EXTERNAL_KEY;

	/**
	 * Defines the SpeedKnots measurement.
	 * <p>
	 * <ul>
	 * <li><b>SpeedKnots</b></li>
	 * </ul>
	 * </p>
	 * @see #SpeedKnots
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#WRITE_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>SpeedKnots</b>/error"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String SPEED_KNOTS_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.SPEED_KNOTS_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the SpeedKPHReport signal.
	 * <p>
	 * <ul>
	 * <li><b>SpeedKPH</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String SpeedKPHReport = "SpeedKPHReport"; //$NON-NLS-1$

	/**
	 * Defines the SpeedKPHReport signal.
	 * <p>
	 * <ul>
	 * <li><b>SpeedKPH</b></li>
	 * </ul>
	 * </p>
	 * @see #SpeedKPHReport
	 * The value of this field is "<i>prefix/<i><b>SpeedKPHReport</b>"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String SPEED_KPH_REPORT_EXTERNAL_KEY = "SpeedKPHReport"; //$NON-NLS-1$

	/**
	 * Defines the SpeedKPHReport signal.
	 * <p>
	 * <ul>
	 * <li><b>SpeedKPH</b></li>
	 * </ul>
	 * </p>
	 * @see #SpeedKPHReport
	 * The value of this field is "<i>prefix/<i><b>SpeedKPHReport</b>/trigger"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String SPEED_KPH_REPORT_TRIGGER_EXTERNAL_KEY = GpsNmeaDeviceService.SPEED_KPH_REPORT_EXTERNAL_KEY + NotificationService.TRIGGER_EXTERNAL_KEY;

	/**
	 * Defines the SpeedKPHReport signal.
	 * <p>
	 * <ul>
	 * <li><b>SpeedKPH</b></li>
	 * </ul>
	 * </p>
	 * @see #SpeedKPHReport
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#TRIGGER_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>SpeedKPHReport</b>/error"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String SPEED_KPH_REPORT_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.SPEED_KPH_REPORT_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the SpeedKPH measurement.
	 * <p>
	 * <ul>
	 * <li><b>SpeedKPH</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String SpeedKPH = "SpeedKPH"; //$NON-NLS-1$

	/**
	 * Defines the SpeedKPH measurement.
	 * <p>
	 * <ul>
	 * <li><b>SpeedKPH</b></li>
	 * </ul>
	 * </p>
	 * @see #SpeedKPH
	 * The value of this field is "<i>prefix/<i><b>SpeedKPH</b>"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String SPEED_KPH_EXTERNAL_KEY = "SpeedKPH"; //$NON-NLS-1$

	/**
	 * Defines the SpeedKPH measurement.
	 * <p>
	 * <ul>
	 * <li><b>SpeedKPH</b></li>
	 * </ul>
	 * </p>
	 * @see #SpeedKPH
	 * The value of this field is "<i>prefix/<i><b>SpeedKPH</b>/get"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String SPEED_KPH_GET_EXTERNAL_KEY = GpsNmeaDeviceService.SPEED_KPH_EXTERNAL_KEY + NotificationService.GET_EXTERNAL_KEY;

	/**
	 * Defines the SpeedKPH measurement.
	 * <p>
	 * <ul>
	 * <li><b>SpeedKPH</b></li>
	 * </ul>
	 * </p>
	 * @see #SpeedKPH
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>SpeedKPH</b>/read"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String SPEED_KPH_READ_EXTERNAL_KEY = GpsNmeaDeviceService.SPEED_KPH_EXTERNAL_KEY + NotificationService.READ_EXTERNAL_KEY;

	/**
	 * Defines the SpeedKPH measurement.
	 * <p>
	 * <ul>
	 * <li><b>SpeedKPH</b></li>
	 * </ul>
	 * </p>
	 * @see #SpeedKPH
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#WRITE_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>SpeedKPH</b>/write"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String SPEED_KPH_WRITE_EXTERNAL_KEY = GpsNmeaDeviceService.SPEED_KPH_EXTERNAL_KEY + NotificationService.WRITE_EXTERNAL_KEY;

	/**
	 * Defines the SpeedKPH measurement.
	 * <p>
	 * <ul>
	 * <li><b>SpeedKPH</b></li>
	 * </ul>
	 * </p>
	 * @see #SpeedKPH
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#WRITE_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>SpeedKPH</b>/error"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String SPEED_KPH_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.SPEED_KPH_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the TrackReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Track</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String TrackReport = "TrackReport"; //$NON-NLS-1$

	/**
	 * Defines the TrackReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Track</b></li>
	 * </ul>
	 * </p>
	 * @see #TrackReport
	 * The value of this field is "<i>prefix/<i><b>TrackReport</b>"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String TRACK_REPORT_EXTERNAL_KEY = "TrackReport"; //$NON-NLS-1$

	/**
	 * Defines the TrackReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Track</b></li>
	 * </ul>
	 * </p>
	 * @see #TrackReport
	 * The value of this field is "<i>prefix/<i><b>TrackReport</b>/trigger"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String TRACK_REPORT_TRIGGER_EXTERNAL_KEY = GpsNmeaDeviceService.TRACK_REPORT_EXTERNAL_KEY + NotificationService.TRIGGER_EXTERNAL_KEY;

	/**
	 * Defines the TrackReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Track</b></li>
	 * </ul>
	 * </p>
	 * @see #TrackReport
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#TRIGGER_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>TrackReport</b>/error"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String TRACK_REPORT_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.TRACK_REPORT_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the Track measurement.
	 * <p>
	 * <ul>
	 * <li><b>Track</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String Track = "Track"; //$NON-NLS-1$

	/**
	 * Defines the Track measurement.
	 * <p>
	 * <ul>
	 * <li><b>Track</b></li>
	 * </ul>
	 * </p>
	 * @see #Track
	 * The value of this field is "<i>prefix/<i><b>Track</b>"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String TRACK_EXTERNAL_KEY = "Track"; //$NON-NLS-1$

	/**
	 * Defines the Track measurement.
	 * <p>
	 * <ul>
	 * <li><b>Track</b></li>
	 * </ul>
	 * </p>
	 * @see #Track
	 * The value of this field is "<i>prefix/<i><b>Track</b>/get"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String TRACK_GET_EXTERNAL_KEY = GpsNmeaDeviceService.TRACK_EXTERNAL_KEY + NotificationService.GET_EXTERNAL_KEY;

	/**
	 * Defines the Track measurement.
	 * <p>
	 * <ul>
	 * <li><b>Track</b></li>
	 * </ul>
	 * </p>
	 * @see #Track
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>Track</b>/read"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String TRACK_READ_EXTERNAL_KEY = GpsNmeaDeviceService.TRACK_EXTERNAL_KEY + NotificationService.READ_EXTERNAL_KEY;

	/**
	 * Defines the Track measurement.
	 * <p>
	 * <ul>
	 * <li><b>Track</b></li>
	 * </ul>
	 * </p>
	 * @see #Track
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#WRITE_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>Track</b>/write"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String TRACK_WRITE_EXTERNAL_KEY = GpsNmeaDeviceService.TRACK_EXTERNAL_KEY + NotificationService.WRITE_EXTERNAL_KEY;

	/**
	 * Defines the Track measurement.
	 * <p>
	 * <ul>
	 * <li><b>Track</b></li>
	 * </ul>
	 * </p>
	 * @see #Track
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#WRITE_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>Track</b>/error"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String TRACK_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.TRACK_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the TrackMagneticReport signal.
	 * <p>
	 * <ul>
	 * <li><b>TrackMagnetic</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String TrackMagneticReport = "TrackMagneticReport"; //$NON-NLS-1$

	/**
	 * Defines the TrackMagneticReport signal.
	 * <p>
	 * <ul>
	 * <li><b>TrackMagnetic</b></li>
	 * </ul>
	 * </p>
	 * @see #TrackMagneticReport
	 * The value of this field is "<i>prefix/<i><b>TrackMagneticReport</b>"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String TRACK_MAGNETIC_REPORT_EXTERNAL_KEY = "TrackMagneticReport"; //$NON-NLS-1$

	/**
	 * Defines the TrackMagneticReport signal.
	 * <p>
	 * <ul>
	 * <li><b>TrackMagnetic</b></li>
	 * </ul>
	 * </p>
	 * @see #TrackMagneticReport
	 * The value of this field is "<i>prefix/<i><b>TrackMagneticReport</b>/trigger"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String TRACK_MAGNETIC_REPORT_TRIGGER_EXTERNAL_KEY = GpsNmeaDeviceService.TRACK_MAGNETIC_REPORT_EXTERNAL_KEY + NotificationService.TRIGGER_EXTERNAL_KEY;

	/**
	 * Defines the TrackMagneticReport signal.
	 * <p>
	 * <ul>
	 * <li><b>TrackMagnetic</b></li>
	 * </ul>
	 * </p>
	 * @see #TrackMagneticReport
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#TRIGGER_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>TrackMagneticReport</b>/error"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String TRACK_MAGNETIC_REPORT_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.TRACK_MAGNETIC_REPORT_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the TrackMagnetic measurement.
	 * <p>
	 * <ul>
	 * <li><b>TrackMagnetic</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String TrackMagnetic = "TrackMagnetic"; //$NON-NLS-1$

	/**
	 * Defines the TrackMagnetic measurement.
	 * <p>
	 * <ul>
	 * <li><b>TrackMagnetic</b></li>
	 * </ul>
	 * </p>
	 * @see #TrackMagnetic
	 * The value of this field is "<i>prefix/<i><b>TrackMagnetic</b>"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String TRACK_MAGNETIC_EXTERNAL_KEY = "TrackMagnetic"; //$NON-NLS-1$

	/**
	 * Defines the TrackMagnetic measurement.
	 * <p>
	 * <ul>
	 * <li><b>TrackMagnetic</b></li>
	 * </ul>
	 * </p>
	 * @see #TrackMagnetic
	 * The value of this field is "<i>prefix/<i><b>TrackMagnetic</b>/get"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String TRACK_MAGNETIC_GET_EXTERNAL_KEY = GpsNmeaDeviceService.TRACK_MAGNETIC_EXTERNAL_KEY + NotificationService.GET_EXTERNAL_KEY;

	/**
	 * Defines the TrackMagnetic measurement.
	 * <p>
	 * <ul>
	 * <li><b>TrackMagnetic</b></li>
	 * </ul>
	 * </p>
	 * @see #TrackMagnetic
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>TrackMagnetic</b>/read"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String TRACK_MAGNETIC_READ_EXTERNAL_KEY = GpsNmeaDeviceService.TRACK_MAGNETIC_EXTERNAL_KEY + NotificationService.READ_EXTERNAL_KEY;

	/**
	 * Defines the TrackMagnetic measurement.
	 * <p>
	 * <ul>
	 * <li><b>TrackMagnetic</b></li>
	 * </ul>
	 * </p>
	 * @see #TrackMagnetic
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#WRITE_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>TrackMagnetic</b>/write"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String TRACK_MAGNETIC_WRITE_EXTERNAL_KEY = GpsNmeaDeviceService.TRACK_MAGNETIC_EXTERNAL_KEY + NotificationService.WRITE_EXTERNAL_KEY;

	/**
	 * Defines the TrackMagnetic measurement.
	 * <p>
	 * <ul>
	 * <li><b>TrackMagnetic</b></li>
	 * </ul>
	 * </p>
	 * @see #TrackMagnetic
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#WRITE_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>TrackMagnetic</b>/error"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String TRACK_MAGNETIC_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.TRACK_MAGNETIC_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the AltitudeReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Altitude</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String AltitudeReport = "AltitudeReport"; //$NON-NLS-1$

	/**
	 * Defines the AltitudeReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Altitude</b></li>
	 * </ul>
	 * </p>
	 * @see #AltitudeReport
	 * The value of this field is "<i>prefix/<i><b>AltitudeReport</b>"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String ALTITUDE_REPORT_EXTERNAL_KEY = "AltitudeReport"; //$NON-NLS-1$

	/**
	 * Defines the AltitudeReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Altitude</b></li>
	 * </ul>
	 * </p>
	 * @see #AltitudeReport
	 * The value of this field is "<i>prefix/<i><b>AltitudeReport</b>/trigger"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String ALTITUDE_REPORT_TRIGGER_EXTERNAL_KEY = GpsNmeaDeviceService.ALTITUDE_REPORT_EXTERNAL_KEY + NotificationService.TRIGGER_EXTERNAL_KEY;

	/**
	 * Defines the AltitudeReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Altitude</b></li>
	 * </ul>
	 * </p>
	 * @see #AltitudeReport
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#TRIGGER_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>AltitudeReport</b>/error"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String ALTITUDE_REPORT_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.ALTITUDE_REPORT_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the Altitude measurement.
	 * <p>
	 * <ul>
	 * <li><b>Altitude</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String Altitude = "Altitude"; //$NON-NLS-1$

	/**
	 * Defines the Altitude measurement.
	 * <p>
	 * <ul>
	 * <li><b>Altitude</b></li>
	 * </ul>
	 * </p>
	 * @see #Altitude
	 * The value of this field is "<i>prefix/<i><b>Altitude</b>"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String ALTITUDE_EXTERNAL_KEY = "Altitude"; //$NON-NLS-1$

	/**
	 * Defines the Altitude measurement.
	 * <p>
	 * <ul>
	 * <li><b>Altitude</b></li>
	 * </ul>
	 * </p>
	 * @see #Altitude
	 * The value of this field is "<i>prefix/<i><b>Altitude</b>/get"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String ALTITUDE_GET_EXTERNAL_KEY = GpsNmeaDeviceService.ALTITUDE_EXTERNAL_KEY + NotificationService.GET_EXTERNAL_KEY;

	/**
	 * Defines the Altitude measurement.
	 * <p>
	 * <ul>
	 * <li><b>Altitude</b></li>
	 * </ul>
	 * </p>
	 * @see #Altitude
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>Altitude</b>/read"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String ALTITUDE_READ_EXTERNAL_KEY = GpsNmeaDeviceService.ALTITUDE_EXTERNAL_KEY + NotificationService.READ_EXTERNAL_KEY;

	/**
	 * Defines the Altitude measurement.
	 * <p>
	 * <ul>
	 * <li><b>Altitude</b></li>
	 * </ul>
	 * </p>
	 * @see #Altitude
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#WRITE_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>Altitude</b>/write"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String ALTITUDE_WRITE_EXTERNAL_KEY = GpsNmeaDeviceService.ALTITUDE_EXTERNAL_KEY + NotificationService.WRITE_EXTERNAL_KEY;

	/**
	 * Defines the Altitude measurement.
	 * <p>
	 * <ul>
	 * <li><b>Altitude</b></li>
	 * </ul>
	 * </p>
	 * @see #Altitude
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#WRITE_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>Altitude</b>/error"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String ALTITUDE_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.ALTITUDE_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the QualityReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Quality</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String QualityReport = "QualityReport"; //$NON-NLS-1$

	/**
	 * Defines the QualityReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Quality</b></li>
	 * </ul>
	 * </p>
	 * @see #QualityReport
	 * The value of this field is "<i>prefix/<i><b>QualityReport</b>"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String QUALITY_REPORT_EXTERNAL_KEY = "QualityReport"; //$NON-NLS-1$

	/**
	 * Defines the QualityReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Quality</b></li>
	 * </ul>
	 * </p>
	 * @see #QualityReport
	 * The value of this field is "<i>prefix/<i><b>QualityReport</b>/trigger"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String QUALITY_REPORT_TRIGGER_EXTERNAL_KEY = GpsNmeaDeviceService.QUALITY_REPORT_EXTERNAL_KEY + NotificationService.TRIGGER_EXTERNAL_KEY;

	/**
	 * Defines the QualityReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Quality</b></li>
	 * </ul>
	 * </p>
	 * @see #QualityReport
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#TRIGGER_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>QualityReport</b>/error"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String QUALITY_REPORT_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.QUALITY_REPORT_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the Quality measurement.
	 * <p>
	 * <ul>
	 * <li><b>Quality</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String Quality = "Quality"; //$NON-NLS-1$

	/**
	 * Defines the Quality measurement.
	 * <p>
	 * <ul>
	 * <li><b>Quality</b></li>
	 * </ul>
	 * </p>
	 * @see #Quality
	 * The value of this field is "<i>prefix/<i><b>Quality</b>"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String QUALITY_EXTERNAL_KEY = "Quality"; //$NON-NLS-1$

	/**
	 * Defines the Quality measurement.
	 * <p>
	 * <ul>
	 * <li><b>Quality</b></li>
	 * </ul>
	 * </p>
	 * @see #Quality
	 * The value of this field is "<i>prefix/<i><b>Quality</b>/get"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String QUALITY_GET_EXTERNAL_KEY = GpsNmeaDeviceService.QUALITY_EXTERNAL_KEY + NotificationService.GET_EXTERNAL_KEY;

	/**
	 * Defines the Quality measurement.
	 * <p>
	 * <ul>
	 * <li><b>Quality</b></li>
	 * </ul>
	 * </p>
	 * @see #Quality
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>Quality</b>/read"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String QUALITY_READ_EXTERNAL_KEY = GpsNmeaDeviceService.QUALITY_EXTERNAL_KEY + NotificationService.READ_EXTERNAL_KEY;

	/**
	 * Defines the Quality measurement.
	 * <p>
	 * <ul>
	 * <li><b>Quality</b></li>
	 * </ul>
	 * </p>
	 * @see #Quality
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#WRITE_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>Quality</b>/write"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String QUALITY_WRITE_EXTERNAL_KEY = GpsNmeaDeviceService.QUALITY_EXTERNAL_KEY + NotificationService.WRITE_EXTERNAL_KEY;

	/**
	 * Defines the Quality measurement.
	 * <p>
	 * <ul>
	 * <li><b>Quality</b></li>
	 * </ul>
	 * </p>
	 * @see #Quality
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#WRITE_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>Quality</b>/error"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String QUALITY_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.QUALITY_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the NumberSatellitesReport signal.
	 * <p>
	 * <ul>
	 * <li><b>NumberSatellites</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String NumberSatellitesReport = "NumberSatellitesReport"; //$NON-NLS-1$

	/**
	 * Defines the NumberSatellitesReport signal.
	 * <p>
	 * <ul>
	 * <li><b>NumberSatellites</b></li>
	 * </ul>
	 * </p>
	 * @see #NumberSatellitesReport
	 * The value of this field is "<i>prefix/<i><b>NumberSatellitesReport</b>"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String NUMBER_SATELLITES_REPORT_EXTERNAL_KEY = "NumberSatellitesReport"; //$NON-NLS-1$

	/**
	 * Defines the NumberSatellitesReport signal.
	 * <p>
	 * <ul>
	 * <li><b>NumberSatellites</b></li>
	 * </ul>
	 * </p>
	 * @see #NumberSatellitesReport
	 * The value of this field is "<i>prefix/<i><b>NumberSatellitesReport</b>/trigger"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String NUMBER_SATELLITES_REPORT_TRIGGER_EXTERNAL_KEY = GpsNmeaDeviceService.NUMBER_SATELLITES_REPORT_EXTERNAL_KEY + NotificationService.TRIGGER_EXTERNAL_KEY;

	/**
	 * Defines the NumberSatellitesReport signal.
	 * <p>
	 * <ul>
	 * <li><b>NumberSatellites</b></li>
	 * </ul>
	 * </p>
	 * @see #NumberSatellitesReport
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#TRIGGER_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>NumberSatellitesReport</b>/error"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String NUMBER_SATELLITES_REPORT_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.NUMBER_SATELLITES_REPORT_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the NumberSatellites measurement.
	 * <p>
	 * <ul>
	 * <li><b>NumberSatellites</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String NumberSatellites = "NumberSatellites"; //$NON-NLS-1$

	/**
	 * Defines the NumberSatellites measurement.
	 * <p>
	 * <ul>
	 * <li><b>NumberSatellites</b></li>
	 * </ul>
	 * </p>
	 * @see #NumberSatellites
	 * The value of this field is "<i>prefix/<i><b>NumberSatellites</b>"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String NUMBER_SATELLITES_EXTERNAL_KEY = "NumberSatellites"; //$NON-NLS-1$

	/**
	 * Defines the NumberSatellites measurement.
	 * <p>
	 * <ul>
	 * <li><b>NumberSatellites</b></li>
	 * </ul>
	 * </p>
	 * @see #NumberSatellites
	 * The value of this field is "<i>prefix/<i><b>NumberSatellites</b>/get"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String NUMBER_SATELLITES_GET_EXTERNAL_KEY = GpsNmeaDeviceService.NUMBER_SATELLITES_EXTERNAL_KEY + NotificationService.GET_EXTERNAL_KEY;

	/**
	 * Defines the NumberSatellites measurement.
	 * <p>
	 * <ul>
	 * <li><b>NumberSatellites</b></li>
	 * </ul>
	 * </p>
	 * @see #NumberSatellites
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>NumberSatellites</b>/read"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String NUMBER_SATELLITES_READ_EXTERNAL_KEY = GpsNmeaDeviceService.NUMBER_SATELLITES_EXTERNAL_KEY + NotificationService.READ_EXTERNAL_KEY;

	/**
	 * Defines the NumberSatellites measurement.
	 * <p>
	 * <ul>
	 * <li><b>NumberSatellites</b></li>
	 * </ul>
	 * </p>
	 * @see #NumberSatellites
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#WRITE_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>NumberSatellites</b>/write"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String NUMBER_SATELLITES_WRITE_EXTERNAL_KEY = GpsNmeaDeviceService.NUMBER_SATELLITES_EXTERNAL_KEY + NotificationService.WRITE_EXTERNAL_KEY;

	/**
	 * Defines the NumberSatellites measurement.
	 * <p>
	 * <ul>
	 * <li><b>NumberSatellites</b></li>
	 * </ul>
	 * </p>
	 * @see #NumberSatellites
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#WRITE_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>NumberSatellites</b>/error"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String NUMBER_SATELLITES_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.NUMBER_SATELLITES_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the DateReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Date</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String DateReport = "DateReport"; //$NON-NLS-1$

	/**
	 * Defines the DateReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Date</b></li>
	 * </ul>
	 * </p>
	 * @see #DateReport
	 * The value of this field is "<i>prefix/<i><b>DateReport</b>"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String DATE_REPORT_EXTERNAL_KEY = "DateReport"; //$NON-NLS-1$

	/**
	 * Defines the DateReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Date</b></li>
	 * </ul>
	 * </p>
	 * @see #DateReport
	 * The value of this field is "<i>prefix/<i><b>DateReport</b>/trigger"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String DATE_REPORT_TRIGGER_EXTERNAL_KEY = GpsNmeaDeviceService.DATE_REPORT_EXTERNAL_KEY + NotificationService.TRIGGER_EXTERNAL_KEY;

	/**
	 * Defines the DateReport signal.
	 * <p>
	 * <ul>
	 * <li><b>Date</b></li>
	 * </ul>
	 * </p>
	 * @see #DateReport
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#TRIGGER_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>DateReport</b>/error"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String DATE_REPORT_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.DATE_REPORT_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * The Date measurement contains a string in ddmmyy format.
	 * <p>
	 * <ul>
	 * <li><b>Date</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String Date = "Date"; //$NON-NLS-1$

	/**
	 * The Date measurement contains a string in ddmmyy format.
	 * <p>
	 * <ul>
	 * <li><b>Date</b></li>
	 * </ul>
	 * </p>
	 * @see #Date
	 * The value of this field is "<i>prefix/<i><b>Date</b>"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String DATE_EXTERNAL_KEY = "Date"; //$NON-NLS-1$

	/**
	 * The Date measurement contains a string in ddmmyy format.
	 * <p>
	 * <ul>
	 * <li><b>Date</b></li>
	 * </ul>
	 * </p>
	 * @see #Date
	 * The value of this field is "<i>prefix/<i><b>Date</b>/get"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String DATE_GET_EXTERNAL_KEY = GpsNmeaDeviceService.DATE_EXTERNAL_KEY + NotificationService.GET_EXTERNAL_KEY;

	/**
	 * The Date measurement contains a string in ddmmyy format.
	 * <p>
	 * <ul>
	 * <li><b>Date</b></li>
	 * </ul>
	 * </p>
	 * @see #Date
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>Date</b>/read"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String DATE_READ_EXTERNAL_KEY = GpsNmeaDeviceService.DATE_EXTERNAL_KEY + NotificationService.READ_EXTERNAL_KEY;

	/**
	 * The Date measurement contains a string in ddmmyy format.
	 * <p>
	 * <ul>
	 * <li><b>Date</b></li>
	 * </ul>
	 * </p>
	 * @see #Date
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#WRITE_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>Date</b>/write"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String DATE_WRITE_EXTERNAL_KEY = GpsNmeaDeviceService.DATE_EXTERNAL_KEY + NotificationService.WRITE_EXTERNAL_KEY;

	/**
	 * The Date measurement contains a string in ddmmyy format.
	 * <p>
	 * <ul>
	 * <li><b>Date</b></li>
	 * </ul>
	 * </p>
	 * @see #Date
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#WRITE_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>Date</b>/error"
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String DATE_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.DATE_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the HorizontalDilutionOfPrecisionReport signal.
	 * <p>
	 * <ul>
	 * <li><b>HorizontalDilutionOfPrecision</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String HorizontalDilutionOfPrecisionReport = "HorizontalDilutionOfPrecisionReport"; //$NON-NLS-1$

	/**
	 * Defines the HorizontalDilutionOfPrecisionReport signal.
	 * <p>
	 * <ul>
	 * <li><b>HorizontalDilutionOfPrecision</b></li>
	 * </ul>
	 * </p>
	 * @see #HorizontalDilutionOfPrecisionReport
	 * The value of this field is "<i>prefix/<i><b>HorizontalDilutionOfPrecisionReport</b>"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String HORIZONTAL_DILUTION_OF_PRECISION_REPORT_EXTERNAL_KEY = "HorizontalDilutionOfPrecisionReport"; //$NON-NLS-1$

	/**
	 * Defines the HorizontalDilutionOfPrecisionReport signal.
	 * <p>
	 * <ul>
	 * <li><b>HorizontalDilutionOfPrecision</b></li>
	 * </ul>
	 * </p>
	 * @see #HorizontalDilutionOfPrecisionReport
	 * The value of this field is "<i>prefix/<i><b>HorizontalDilutionOfPrecisionReport</b>/trigger"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String HORIZONTAL_DILUTION_OF_PRECISION_REPORT_TRIGGER_EXTERNAL_KEY = GpsNmeaDeviceService.HORIZONTAL_DILUTION_OF_PRECISION_REPORT_EXTERNAL_KEY + NotificationService.TRIGGER_EXTERNAL_KEY;

	/**
	 * Defines the HorizontalDilutionOfPrecisionReport signal.
	 * <p>
	 * <ul>
	 * <li><b>HorizontalDilutionOfPrecision</b></li>
	 * </ul>
	 * </p>
	 * @see #HorizontalDilutionOfPrecisionReport
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#TRIGGER_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>HorizontalDilutionOfPrecisionReport</b>/error"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String HORIZONTAL_DILUTION_OF_PRECISION_REPORT_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.HORIZONTAL_DILUTION_OF_PRECISION_REPORT_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Defines the HorizontalDilutionOfPrecision measurement.
	 * <p>
	 * <ul>
	 * <li><b>HorizontalDilutionOfPrecision</b></li>
	 * </ul>
	 * </p>
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String HorizontalDilutionOfPrecision = "HorizontalDilutionOfPrecision"; //$NON-NLS-1$

	/**
	 * Defines the HorizontalDilutionOfPrecision measurement.
	 * <p>
	 * <ul>
	 * <li><b>HorizontalDilutionOfPrecision</b></li>
	 * </ul>
	 * </p>
	 * @see #HorizontalDilutionOfPrecision
	 * The value of this field is "<i>prefix/<i><b>HorizontalDilutionOfPrecision</b>"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String HORIZONTAL_DILUTION_OF_PRECISION_EXTERNAL_KEY = "HorizontalDilutionOfPrecision"; //$NON-NLS-1$

	/**
	 * Defines the HorizontalDilutionOfPrecision measurement.
	 * <p>
	 * <ul>
	 * <li><b>HorizontalDilutionOfPrecision</b></li>
	 * </ul>
	 * </p>
	 * @see #HorizontalDilutionOfPrecision
	 * The value of this field is "<i>prefix/<i><b>HorizontalDilutionOfPrecision</b>/get"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String HORIZONTAL_DILUTION_OF_PRECISION_GET_EXTERNAL_KEY = GpsNmeaDeviceService.HORIZONTAL_DILUTION_OF_PRECISION_EXTERNAL_KEY + NotificationService.GET_EXTERNAL_KEY;

	/**
	 * Defines the HorizontalDilutionOfPrecision measurement.
	 * <p>
	 * <ul>
	 * <li><b>HorizontalDilutionOfPrecision</b></li>
	 * </ul>
	 * </p>
	 * @see #HorizontalDilutionOfPrecision
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>HorizontalDilutionOfPrecision</b>/read"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String HORIZONTAL_DILUTION_OF_PRECISION_READ_EXTERNAL_KEY = GpsNmeaDeviceService.HORIZONTAL_DILUTION_OF_PRECISION_EXTERNAL_KEY + NotificationService.READ_EXTERNAL_KEY;

	/**
	 * Defines the HorizontalDilutionOfPrecision measurement.
	 * <p>
	 * <ul>
	 * <li><b>HorizontalDilutionOfPrecision</b></li>
	 * </ul>
	 * </p>
	 * @see #HorizontalDilutionOfPrecision
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#WRITE_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>HorizontalDilutionOfPrecision</b>/write"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String HORIZONTAL_DILUTION_OF_PRECISION_WRITE_EXTERNAL_KEY = GpsNmeaDeviceService.HORIZONTAL_DILUTION_OF_PRECISION_EXTERNAL_KEY + NotificationService.WRITE_EXTERNAL_KEY;

	/**
	 * Defines the HorizontalDilutionOfPrecision measurement.
	 * <p>
	 * <ul>
	 * <li><b>HorizontalDilutionOfPrecision</b></li>
	 * </ul>
	 * </p>
	 * @see #HorizontalDilutionOfPrecision
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#GET_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#READ_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#WRITE_EXTERNAL_KEY
	 * @see org.eclipse.soda.dk.notification.service.NotificationService#ERROR_EXTERNAL_KEY
	 * The value of this field is "<i>prefix/<i><b>HorizontalDilutionOfPrecision</b>/error"
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String HORIZONTAL_DILUTION_OF_PRECISION_ERROR_EXTERNAL_KEY = GpsNmeaDeviceService.HORIZONTAL_DILUTION_OF_PRECISION_EXTERNAL_KEY + NotificationService.ERROR_EXTERNAL_KEY;

	/**
	 * Comprehensive list of all the command identifiers.
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String[] ALL_COMMANDS = new String[] {};

	/**
	 * Comprehensive list of all the signal identifiers.
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String[] ALL_SIGNALS = new String[] { GpsNmeaDeviceService.AltitudeReport, GpsNmeaDeviceService.DateReport, GpsNmeaDeviceService.GPGGA, GpsNmeaDeviceService.GPGLL, GpsNmeaDeviceService.GPRMC, GpsNmeaDeviceService.GPVTG,
			GpsNmeaDeviceService.GPZDA, GpsNmeaDeviceService.HorizontalDilutionOfPrecisionReport, GpsNmeaDeviceService.LatitudeReport, GpsNmeaDeviceService.LongitudeReport, GpsNmeaDeviceService.NumberSatellitesReport, GpsNmeaDeviceService.PositionReport,
			GpsNmeaDeviceService.QualityReport, GpsNmeaDeviceService.SpeedKPHReport, GpsNmeaDeviceService.SpeedKnotsReport, GpsNmeaDeviceService.StatusReport, GpsNmeaDeviceService.TimeReport, GpsNmeaDeviceService.TrackMagneticReport,
			GpsNmeaDeviceService.TrackReport };

	/**
	 * Comprehensive list of all the measurement identifiers.
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String[] ALL_MEASUREMENTS = new String[] { GpsNmeaDeviceService.Altitude, GpsNmeaDeviceService.Date, GpsNmeaDeviceService.HorizontalDilutionOfPrecision, GpsNmeaDeviceService.Latitude, GpsNmeaDeviceService.Longitude,
			GpsNmeaDeviceService.NumberSatellites, GpsNmeaDeviceService.Position, GpsNmeaDeviceService.Quality, GpsNmeaDeviceService.SpeedKPH, GpsNmeaDeviceService.SpeedKnots, GpsNmeaDeviceService.Status, GpsNmeaDeviceService.Time,
			GpsNmeaDeviceService.Track, GpsNmeaDeviceService.TrackMagnetic };

	/**
	 * Parameter Day key.
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String Day = "Day"; //$NON-NLS-1$

	/**
	 * Parameter Month key.
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String Month = "Month"; //$NON-NLS-1$

	/**
	 * Parameter Year key.
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String Year = "Year"; //$NON-NLS-1$

	/**
	 * Description of the test.
	 * @since 1.1
	 */
	// Generated field and should not be changed.
	public static final String SERVICE_DESCRIPTION = "Global Positioning System (GPS) National Marine Electronics Association (NMEA) Device"; //$NON-NLS-1$
}
