package org.eclipse.soda.dk.gps.nmea.simulator;

/*************************************************************************
 * Copyright (c) 2008, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import java.util.Calendar;
import org.eclipse.soda.dk.connection.service.ConnectionService;
import org.eclipse.soda.dk.data.Degree;
import org.eclipse.soda.dk.data.LatitudeData;
import org.eclipse.soda.dk.data.LongitudeData;
import org.eclipse.soda.dk.message.AsciiMessage;
import org.eclipse.soda.dk.message.service.MessageService;
import org.eclipse.soda.dk.tcpip.server.connection.TcpipServerConnection;
import org.eclipse.soda.dk.tcpip.server.connection.service.TcpipServerConnectionService;
import org.eclipse.soda.dk.transport.ConnectionTransport;
import org.eclipse.soda.dk.transport.service.TransportService;

/**
 * GPS NMEA Transport.
 * <p>
 * The devicekit properties keys and default values.
 * <table>
 * <tr>
 * <td>gpsnmeatransport.hardwareflowcontrol</td>
 * <td>0</td>
 * </tr>
 * <tr>
 * <td>gpsnmeatransport.parity</td>
 * <td>none</td>
 * </tr>
 * <tr>
 * <td>gpsnmeatransport.stopbits</td>
 * <td>1</td>
 * </tr>
 * <tr>
 * <td>gpsnmeatransport.comport</td>
 * <td>1</td>
 * </tr>
 * <tr>
 * <td>gpsnmeatransport.readintervaltimeout</td>
 * <td>50</td>
 * </tr>
 * <tr>
 * <td>gpsnmeatransport.softwareflowcontrol</td>
 * <td>0</td>
 * </tr>
 * <tr>
 * <td>gpsnmeatransport.writetotaltimeout</td>
 * <td>100</td>
 * </tr>
 * <tr>
 * <td>gpsnmeatransport.databits</td>
 * <td>8</td>
 * </tr>
 * <tr>
 * <td>gpsnmeatransport.readtotaltimeout</td>
 * <td>1000</td>
 * </tr>
 * <tr>
 * <td>gpsnmeatransport.baudrate</td>
 * <td>4800</td>
 * </tr>
 * <tr>
 * <td>gpsnmeatransport.linger</td>
 * <td>-1</td>
 * </tr>
 * <tr>
 * <td>gpsnmeatransport.readtimeout</td>
 * <td>1000</td>
 * </tr>
 * <tr>
 * <td>gpsnmeatransport.readsize</td>
 * <td>-1</td>
 * </tr>
 * <tr>
 * <td>gpsnmeatransport.localport</td>
 * <td>-1</td>
 * </tr>
 * <tr>
 * <td>gpsnmeatransport.host</td>
 * <td>localhost</td>
 * </tr>
 * <tr>
 * <td>gpsnmeatransport.writesize</td>
 * <td>-1</td>
 * </tr>
 * <tr>
 * <td>gpsnmeatransport.remoteport</td>
 * <td>8901</td>
 * </tr>
 * <tr>
 * <td>gpsnmeatransport.connection</td>
 * <td>serial</td>
 * </tr>
 * </table>
 * <xmp> gpsnmeatransport.hardwareflowcontrol=0 gpsnmeatransport.parity=none gpsnmeatransport.stopbits=1 gpsnmeatransport.comport=1 gpsnmeatransport.readintervaltimeout=50 gpsnmeatransport.softwareflowcontrol=0 gpsnmeatransport.writetotaltimeout=100
 * gpsnmeatransport.databits=8 gpsnmeatransport.readtotaltimeout=1000 gpsnmeatransport.baudrate=4800 </xmp> <xmp> gpsnmeatransport.linger=-1 gpsnmeatransport.readtimeout=1000 gpsnmeatransport.readsize=-1 gpsnmeatransport.localport=-1
 * gpsnmeatransport.host=localhost gpsnmeatransport.writesize=-1 gpsnmeatransport.remoteport=8901 </xmp> <xmp> gpsnmeatransport.connection=serial </xmp>
 * <p>
 * The list of exported services:
 * @see org.eclipse.soda.dk.transport.service.TransportService
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class GpsNmeaSimulator extends ConnectionTransport implements TransportService {
	/**
	 * Defines the class name.
	 */
	public static final String CLASS_NAME = "org.eclipse.soda.dk.gps.nmea.transport.GpsNmeaTransport"; //$NON-NLS-1$

	/**
	 * Define the hex table (byte[]) constant.
	 */
	public static final byte[] HEX_TABLE = { (byte) '0', (byte) '1', (byte) '2', (byte) '3', (byte) '4', (byte) '5', (byte) '6', (byte) '7', (byte) '8', (byte) '9', (byte) 'A', (byte) 'B', (byte) 'C', (byte) 'D', (byte) 'E', (byte) 'F' };

	/**
	 * Constructs a new instance of the GpsNmeaTransport class.
	 */
	public GpsNmeaSimulator() {
		super();
	}

	/**
	 * Main with the specified arguments parameter.
	 * @param arguments
	 *		The arguments (<code>String[]</code>) parameter.
	 */
	public static void main(final String[] arguments) {
		final GpsNmeaSimulator gpsNmeaSimulator = new GpsNmeaSimulator();
		gpsNmeaSimulator.start();
		try {
			Thread.sleep(600000);
		} catch (final InterruptedException exception) {
			exception.printStackTrace();
		}
	}

	/**
	 * Gets the default connection (ConnectionService) value.
	 * @return ConnectionService The default connection used by this transport.
	 */
	public ConnectionService getDefaultConnection() {
		return getDefaultTcpipServerConnection();
	}

	/**
	 * Gets the default TCPIP server connection (TcpipServerConnectionService) value.
	 * @return The default TCPIP server connection (<code>TcpipServerConnectionService</code>) value.
	 */
	public TcpipServerConnectionService getDefaultTcpipServerConnection() {
		/* This is a generated method and should not be edited. */
		return new TcpipServerConnection(getInt("gpsnmeasimulator.remoteport", 8901)); //$NON-NLS-1$
	}

	/**
	 * Get latitude with the specified NMEA string parameter and return the LatitudeData result.
	 * @param nmeaString
	 *		The NMEA string (<code>String</code>) parameter.
	 * @return Results of the get latitude (<code>LatitudeData</code>) value.
	 */
	public LatitudeData getLatitude(final String nmeaString) {
		try {
			final int lenght = nmeaString.length();
			final String data = nmeaString.substring(0, lenght - 1);
			int value = Degree.parseNmeaDegree(data);
			if (nmeaString.endsWith("S")) { //$NON-NLS-1$
				value = -value;
			}
			return new LatitudeData(value);
		} catch (final NumberFormatException exception) {
			return null;
		}
	}

	/**
	 * Get longitude with the specified nmea string parameter and return the LongitudeData result.
	 * @param nmeaString
	 *		The NMEA string (<code>String</code>) parameter.
	 * @return Results of the get longitude (<code>LongitudeData</code>) value.
	 */
	public LongitudeData getLongitude(final String nmeaString) {
		try {
			final int lenght = nmeaString.length();
			final String data = nmeaString.substring(0, lenght - 1);
			int value = Degree.parseNmeaDegree(data);
			if (nmeaString.endsWith("W")) { //$NON-NLS-1$
				value = -value;
			}
			return new LongitudeData(value);
		} catch (final NumberFormatException exception) {
			return null;
		}
	}

	/**
	 * Process input.
	 * @throws Exception Exception.
	 * @see #processInput(byte[],int)
	 */
	public void processInput() throws Exception {
		LatitudeData latitudeData = getLatitude("3547.426N"); //$NON-NLS-1$
		LongitudeData longitudeData = getLongitude("07842.076W"); //$NON-NLS-1$
		final Number latitudeDelta = new Float(.01);
		final Number longitudeDelta = new Float(.01);
		while (isRunning()) {
			final long timenow = System.currentTimeMillis();
			final long delay = 1000 - (timenow % 1000);
			if (delay > 10) {
				sleep(delay);
			}
			final StringBuffer buffer = new StringBuffer(100);
			final Calendar calendar = Calendar.getInstance();
			final int hour = calendar.get(Calendar.HOUR_OF_DAY);
			final int minute = calendar.get(Calendar.MINUTE);
			final int second = calendar.get(Calendar.SECOND);
			buffer.append("$GPGGA,"); //$NON-NLS-1$
			final String hourString = Integer.toString(hour);
			final String minuteString = Integer.toString(minute);
			final String secondString = Integer.toString(second);
			buffer.append(hourString);
			if (minuteString.length() == 1) {
				buffer.append('0');
			}
			buffer.append(minuteString);
			if (secondString.length() == 1) {
				buffer.append('0');
			}
			buffer.append(secondString);
			buffer.append(".0,"); //$NON-NLS-1$
			buffer.append(latitudeData.toNmeaString());
			buffer.append(',');
			buffer.append(longitudeData.toNmeaString());
			buffer.append(",1,4,1.94,00141,M,-033,M,,"); //$NON-NLS-1$
			MessageService message = new AsciiMessage(buffer.toString());
			write(message);
			longitudeData.add(longitudeDelta);
			latitudeData = new LatitudeData((int) ((latitudeDelta.doubleValue()) * Degree.THOUSAND) + latitudeData.getThousandSeconds());
			longitudeData = new LongitudeData((int) ((longitudeDelta.doubleValue()) * Degree.THOUSAND) + longitudeData.getThousandSeconds());
		}
	}

	/**
	 * Process the input bytes and notify listeners of any messages found.
	 * @param bytes
	 *		The bytes (<code>byte[]</code>) parameter.
	 * @param length
	 *		The length (<code>int</code>) parameter.
	 * @return Results of the process input (<code>int</code>) value.
	 * @throws Exception Exception.
	 * @see #processInput()
	 */
	public int processInput(final byte[] bytes, final int length) throws Exception {
		return length;
	}

	/**
	 * Sets user-defined variables to use in the test.
	 * <p>
	 * User defined properties and default values.
	 * <table>
	 * <tr>
	 * <td>retrytime</td>
	 * <td>DEFAULT_RETRY_TIME</td>
	 * </tr>
	 * <tr>
	 * <td>noactivitytimeout</td>
	 * <td>DEFAULT_NO_ACTIVITY_TIMEOUT</td>
	 * </tr>
	 * </table>
	 * @see org.eclipse.soda.dk.transport.Transport#setup()
	 */
	public void setup() {
		/* This is a generated method and should not be edited. */
		super.setup();
		setRetryTime(getLong("gpsnmeatransport.retrytime", getRetryTime())); //$NON-NLS-1$
		setNoActivityTimeout(getLong("gpsnmeatransport.noactivitytimeout", getNoActivityTimeout())); //$NON-NLS-1$
	}

	/**
	 * Write with the specified message parameter.
	 * @param message
	 *		The message (<code>MessageService</code>) parameter.
	 * @throws Exception Exception.
	 */
	protected void write(final MessageService message) throws Exception {
		final byte[] obytes = message.getBytes();
		final int length = obytes.length;
		final byte[] mbytes = new byte[length + 5];
		int index = 0;
		int checksum = '$';
		for (index = 0; index < length; index++) {
			mbytes[index] = obytes[index];
			checksum = checksum ^ mbytes[index];
		}
		checksum = checksum & 0xff;
		mbytes[index++] = '*';
		mbytes[index++] = HEX_TABLE[checksum >> 4];
		mbytes[index++] = HEX_TABLE[checksum & 0xf];
		mbytes[index++] = CR;
		mbytes[index++] = LF;
		write(mbytes);
	}
}
