package org.eclipse.soda.dk.gps.nmea.transport;

/*************************************************************************
 * Copyright (c) 1998, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import org.eclipse.soda.dk.core.EscObject;
import org.eclipse.soda.dk.data.Degree;
import org.eclipse.soda.dk.data.LatitudeData;
import org.eclipse.soda.dk.data.LongitudeData;
import org.eclipse.soda.dk.data.PositionData;
import org.eclipse.soda.dk.message.AsciiMessage;

/**
 * The <b>GpsNmeaMessage</b> class implements the MessageService interface.
 * @see java.lang.Cloneable
 * @see org.eclipse.soda.dk.message.service.MessageService
 * @see org.eclipse.soda.dk.parameter.service.ParameterService
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class GpsNmeaMessage extends AsciiMessage {
	/**
	 * Define the checksum valid (boolean) field.
	 */
	private boolean checksumValid = false;

	/**
	 * Define the field count (int) field.
	 */
	private int fieldCount;

	/**
	 * Define the field info (int[]) field.
	 */
	private int[] fieldInfo;

	/**
	 * Constructs a standard <code>GpsNmeaMessage</code> object.
	 * @see #GpsNmeaMessage(byte[])
	 */
	public GpsNmeaMessage() {
		this(EscObject.EMPTY_BYTES);
	}

	/**
	 * Constructs an <code>GpsNmeaMessage</code> object using the input parameter(s).
	 * @param bytes byte[]
	 * @see #GpsNmeaMessage()
	 */
	public GpsNmeaMessage(final byte[] bytes) {
		super(bytes);
		setBytes(bytes);
	}

	/**
	 * Get with the specified field name parameter and return the Object result.
	 * @param fieldName	The field name (<code>Object</code>) parameter.
	 * @return	Results of the get (<code>Object</code>) value.
	 */
	public Object get(final Object fieldName) {
		if ("Latitude".equals(fieldName)) { //$NON-NLS-1$
			return getLatitude();
		}
		if ("Longitude".equals(fieldName)) { //$NON-NLS-1$
			return getLongitude();
		}
		if ("Position".equals(fieldName)) { //$NON-NLS-1$
			final LatitudeData latitude = getLatitude();
			final LongitudeData longitude = getLongitude();
			if ((latitude != null) && (longitude != null)) {
				return new PositionData(latitude, longitude);
			}
			return null;
		}
		return getData(Integer.parseInt((String) fieldName, 10));
	}

	/**
	 * Perform the getData method and return the <code>Object</code> result.
	 * @param index <code>int</code>
	 * @return	Results of the get data (<code>Object</code>) value.
	 */
	public Object getData(final int index) {
		if ((index >= 0) && (index < this.fieldCount)) {
			return new String(getBytes(), this.fieldInfo[index], (this.fieldInfo[index + 1] - this.fieldInfo[index]) - 1);
		}
		return null;
	}

	/**
	 * Gets the <code>int</code> fieldCount property value.
	 * @return	Results of the get field count (<code>int</code>) value.
	 */
	public int getFieldCount() {
		return this.fieldCount;
	}

	/**
	 * Gets the <code>int []</code> fieldInfo property value.
	 * @return	Results of the get field info (<code>int[]</code>) value.
	 */
	public int[] getFieldInfo() {
		if (this.fieldInfo == null) {
			this.fieldInfo = new int[80];
		}
		return this.fieldInfo;
	}

	/**
	 * Gets the field position (int) value.
	 * @return	The field position (<code>int</code>) value.
	 * @throws RuntimeException Runtime Exception.
	 */
	public int getFieldPosition() throws RuntimeException {
		final Object data = getData(0);
		if ("$GPGGA".equals(data)) { //$NON-NLS-1$
			return 2;
		}
		if ("$GPRMC".equals(data)) { //$NON-NLS-1$
			return 3;
		}
		if ("$GPGLL".equals(data)) { //$NON-NLS-1$
			return 1;
		}
		throw new IllegalArgumentException(String.valueOf(data));
	}

	/**
	 * Gets the latitude (LatitudeData) value.
	 * @return	The latitude (<code>LatitudeData</code>) value.
	 */
	public LatitudeData getLatitude() {
		try {
			final String data = String.valueOf(getData(getFieldPosition()));
			int value = Degree.parseNmeaDegree(data);
			if ("S".equals(getData(getFieldPosition() + 1))) { //$NON-NLS-1$
				value = -value;
			}
			return new LatitudeData(value);
		} catch (final NumberFormatException exception) {
			return null;
		}
	}

	/**
	 * Gets the longitude (LongitudeData) value.
	 * @return	The longitude (<code>LongitudeData</code>) value.
	 */
	public LongitudeData getLongitude() {
		try {
			final String data = String.valueOf(getData(getFieldPosition() + 2));
			int value = Degree.parseNmeaDegree(data);
			if ("W".equals(getData(getFieldPosition() + 3))) { //$NON-NLS-1$
				value = -value;
			}
			return new LongitudeData(value);
		} catch (final NumberFormatException exception) {
			return null;
		}
	}

	/**
	 * Gets the <code>boolean</code> checksumValid property value.
	 * @return	Results of the is checksum valid (<code>boolean</code>) value.
	 */
	public boolean isChecksumValid() {
		return this.checksumValid;
	}

	/**
	 * Gets the <code>boolean</code> valid property value.
	 * @return	Results of the is valid (<code>boolean</code>) value.
	 * @see #isChecksumValid()
	 */
	public boolean isValid() {
		return (getBytes()[0] == '$') && (isChecksumValid());
	}

	/**
	 * Sets the bytes value.
	 * @param bytes	The bytes (<code>byte[]</code>) parameter.
	 */
	public void setBytes(final byte[] bytes) {
		super.setBytes(bytes);
		if ((bytes == null) || (bytes.length < 1)) {
			return;
		}
		final int length = bytes.length;
		int computedChecksum = 0;
		int runningChecksum = '$';
		this.fieldInfo = new int[length + 1];
		this.fieldCount = 0;
		for (int i = 0; i < length; i++) {
			final byte data = bytes[i];
			if (data == '*') {
				computedChecksum = runningChecksum;
			} else {
				runningChecksum = runningChecksum ^ data;
			}
			if ((data == ',') || (data == '*') || (data == '\n') || (data == '\r')) {
				this.fieldCount++;
				getFieldInfo()[this.fieldCount] = i + 1;
			}
		}
		this.checksumValid = false;
		if (this.fieldCount == 0) {
			this.fieldCount++;
			getFieldInfo()[this.fieldCount] = length + 1;
		} else {
			if (this.fieldCount > 2) {
				final int index = this.fieldCount - 2;
				final int offset = this.fieldInfo[index];
				if ((offset + 1) < length) {
					computedChecksum = computedChecksum & 0xff;
					this.checksumValid = true;
					if (bytes[offset] != GpsNmeaTransport.HEX_TABLE[computedChecksum >> 4]) {
						this.checksumValid = false;
					}
					if (bytes[offset + 1] != GpsNmeaTransport.HEX_TABLE[computedChecksum & 0xf]) {
						this.checksumValid = false;
					}
				}
			}
		}
		return;
	}
}
