package org.eclipse.soda.dk.gps.nmea.transport;

/*************************************************************************
 * Copyright (c) 2007, 2009 IBM.                                         *
 * All rights reserved. This program and the accompanying materials      *
 * are made available under the terms of the Eclipse Public License v1.0 *
 * which accompanies this distribution, and is available at              *
 * http://www.eclipse.org/legal/epl-v10.html                             *
 *                                                                       *
 * Contributors:                                                         *
 *     IBM - initial API and implementation                              *
 ************************************************************************/
import org.eclipse.soda.dk.connection.service.ConnectionService;
import org.eclipse.soda.dk.gps.nmea.transport.service.GpsNmeaTransportService;
import org.eclipse.soda.dk.message.Message;
import org.eclipse.soda.dk.message.service.MessageService;
import org.eclipse.soda.dk.serial.connection.SerialConnection;
import org.eclipse.soda.dk.serial.connection.service.SerialConnectionService;
import org.eclipse.soda.dk.tcpip.connection.TcpipConnection;
import org.eclipse.soda.dk.tcpip.connection.service.TcpipConnectionService;
import org.eclipse.soda.dk.transport.ConnectionTransport;
import org.eclipse.soda.dk.transport.service.TransportService;

/**
 * Global Positioning System (GPS) National Marine Electronics Association (NMEA) Transport.
 * 
 *  <p>The Device Kit properties CONNECTION_KEYS and default values.
 * <table>
 *  
 * 	<tr>
 * 		<td>gpsnmeatransport.databits</td>
 * 		<td>8</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.comport</td>
 * 		<td>1</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.readtotaltimeout</td>
 * 		<td>1000</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.readintervaltimeout</td>
 * 		<td>50</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.hardwareflowcontrol</td>
 * 		<td>0</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.softwareflowcontrol</td>
 * 		<td>0</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.stopbits</td>
 * 		<td>1</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.writetotaltimeout</td>
 * 		<td>100</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.parity</td>
 * 		<td>none</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.baudrate</td>
 * 		<td>4800</td>
 * 	</tr>
 *  
 * 	<tr>
 * 		<td>gpsnmeatransport.writesize</td>
 * 		<td>-1</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.linger</td>
 * 		<td>-1</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.readsize</td>
 * 		<td>-1</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.remoteport</td>
 * 		<td>8901</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.host</td>
 * 		<td>localhost</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.readtimeout</td>
 * 		<td>1000</td>
 * 	</tr>
 * 	<tr>
 * 		<td>gpsnmeatransport.localport</td>
 * 		<td>-1</td>
 * 	</tr>
 *  
 * 	<tr>
 * 		<td>gpsnmeatransport.connection</td>
 * 		<td>serial</td>
 * 	</tr>
 * </table>
 *  
 * <xmp>
 * 	gpsnmeatransport.databits=8
 * 	gpsnmeatransport.comport=1
 * 	gpsnmeatransport.readtotaltimeout=1000
 * 	gpsnmeatransport.readintervaltimeout=50
 * 	gpsnmeatransport.hardwareflowcontrol=0
 * 	gpsnmeatransport.softwareflowcontrol=0
 * 	gpsnmeatransport.stopbits=1
 * 	gpsnmeatransport.writetotaltimeout=100
 * 	gpsnmeatransport.parity=none
 * 	gpsnmeatransport.baudrate=4800
 * </xmp>
 *  
 *  
 * <xmp>
 * 	gpsnmeatransport.writesize=-1
 * 	gpsnmeatransport.linger=-1
 * 	gpsnmeatransport.readsize=-1
 * 	gpsnmeatransport.remoteport=8901
 * 	gpsnmeatransport.host=localhost
 * 	gpsnmeatransport.readtimeout=1000
 * 	gpsnmeatransport.localport=-1
 * </xmp>
 *  
 *  
 * <xmp>
 * 	gpsnmeatransport.connection=serial
 * </xmp>
 *  
 * <p>The list of exported services:
 * @see org.eclipse.soda.dk.gps.nmea.transport.service.GpsNmeaTransportService
 * @see org.eclipse.soda.dk.transport.service.TransportService
 *  
 * @author IBM
 * @version 1.2.0
 * @since 1.0
 */
public class GpsNmeaTransport extends ConnectionTransport implements TransportService, GpsNmeaTransportService {
	/**
	 * Defines the full class name.
	 * @since 1.0
	 */
	// Generated field and should not be changed.
	public static final String CLASS_NAME = "org.eclipse.soda.dk.gps.nmea.transport.GpsNmeaTransport"; //$NON-NLS-1$

	/**
	 * Define the astral (byte[]) constant.
	 */
	private static final byte[] ASTRAL = "ASTRAL\r\n".getBytes(); //$NON-NLS-1$

	/**
	 * Define the hex table (byte[]) constant.
	 */
	public static final byte[] HEX_TABLE = { (byte) '0', (byte) '1', (byte) '2', (byte) '3', (byte) '4', (byte) '5', (byte) '6', (byte) '7', (byte) '8', (byte) '9', (byte) 'A', (byte) 'B', (byte) 'C', (byte) 'D', (byte) 'E', (byte) 'F' };

	/**
	 * Constructs a new instance of the GpsNmeaTransport class.
	 * @since 1.0
	 */
	public GpsNmeaTransport() {
		/* Generated method and should not be changed. */
		super();
	}

	/**
	 * Process the input bytes and notify listeners of any messages found.
	 * @param bytes
	 *		The bytes (<code>byte[]</code>) parameter.
	 * @param length
	 *		The length (<code>int</code>) parameter.
	 * @return Results of the process input (<code>int</code>) value.
	 * @throws Exception Exception.
	 */
	public int processInput(final byte[] bytes, final int length) throws Exception {
		int index = 0;
		Object timestamp = null;
		try {
			for (int i = 0; i < length; i++) {
				if (bytes[i] == LF) {
					if (timestamp == null) {
						timestamp = getCurrentTimestamp();
					}
					final byte[] mbytes = new byte[(i + 1) - index];
					System.arraycopy(bytes, index, mbytes, 0, (i + 1) - index);
					final GpsNmeaMessage message = new GpsNmeaMessage(mbytes);
					if (message.isValid()) {
						fireMessageReceived(timestamp, message);
					} else {
						if (isRunning()) {
							boolean astralMessage = false;
							if (message.length() == ASTRAL.length) {
								astralMessage = true;
								for (int j = 0; j < ASTRAL.length; j++) {
									if (mbytes[j] != ASTRAL[j]) {
										astralMessage = false;
										break;
									}
								}
							}
							if (astralMessage) {
								try {
									write(ASTRAL);
								} catch (final Exception exception) {
									handleError(exception, SEND_EXCEPTION_RESOURCE, new Message(ASTRAL), getHistory());
								}
							} else {
								handleError(null, INVALID_MESSAGE_RESOURCE, message, getHistory());
								setReceivingData(false);
							}
						}
					}
					index = i + 1;
				}
			}
		} catch (final RuntimeException exception) {
			handleError(exception, PROCESS_INPUT_EXCEPTION_RESOURCE, getHistory());
		}
		return index;
	}

	/**
	 * Write with the specified message parameter.
	 * @param message
	 *		The message (<code>MessageService</code>) parameter.
	 * @throws Exception Exception.
	 */
	protected void write(final MessageService message) throws Exception {
		final byte[] obytes = message.getBytes();
		final int length = obytes.length;
		final byte[] mbytes = new byte[length + 5];
		int index = 0;
		int checksum = '$';
		for (index = 0; index < length; index++) {
			mbytes[index] = obytes[index];
			checksum = checksum ^ mbytes[index];
		}
		checksum = checksum & 0xff;
		mbytes[index++] = '*';
		mbytes[index++] = HEX_TABLE[checksum >> 4];
		mbytes[index++] = HEX_TABLE[checksum & 0xf];
		mbytes[index++] = CR;
		mbytes[index++] = LF;
		write(mbytes);
	}

	/**
	 * Gets the default connection.
	 * 
	 * @return ConnectionService The default connection used by this transport.
	 * @since 1.0
	 */
	public ConnectionService getDefaultConnection() {
		/* Generated method and should not be changed. */
		final String type = getString("gpsnmeatransport.connection", SerialConnectionService.CONNECTION_TYPE); //$NON-NLS-1$
		if (type.equals(TcpipConnectionService.CONNECTION_TYPE)) {
			return getDefaultTcpipConnection();
		}
		return getDefaultSerialConnection();
	}

	/**
	 * Gets the default serial connection.
	 * 
	 * @return SerialConnectionService The default serial connection used by this transport.
	 * @since 1.0
	 */
	public SerialConnectionService getDefaultSerialConnection() {
		/* Generated method and should not be changed. */
		return new SerialConnection(getInt(GpsNmeaTransportService.SERIAL_COMPORT_PROPERTY, GpsNmeaTransportService.SERIAL_COMPORT_DEFAULT), //
				getInt(GpsNmeaTransportService.SERIAL_BAUDRATE_PROPERTY, GpsNmeaTransportService.SERIAL_BAUDRATE_DEFAULT), //
				getInt(GpsNmeaTransportService.SERIAL_DATABITS_PROPERTY, GpsNmeaTransportService.SERIAL_DATABITS_DEFAULT), //
				getInt(GpsNmeaTransportService.SERIAL_PARITY_PROPERTY, GpsNmeaTransportService.SERIAL_PARITY_DEFAULT), //
				getInt(GpsNmeaTransportService.SERIAL_STOPBITS_PROPERTY, GpsNmeaTransportService.SERIAL_STOPBITS_DEFAULT), //
				getInt(GpsNmeaTransportService.SERIAL_HARDWAREFLOWCONTROL_PROPERTY, GpsNmeaTransportService.SERIAL_HARDWAREFLOWCONTROL_DEFAULT), //
				getInt(GpsNmeaTransportService.SERIAL_SOFTWAREFLOWCONTROL_PROPERTY, GpsNmeaTransportService.SERIAL_SOFTWAREFLOWCONTROL_DEFAULT), //
				getLong(GpsNmeaTransportService.SERIAL_READTOTALTIMEOUT_PROPERTY, GpsNmeaTransportService.SERIAL_READTOTALTIMEOUT_DEFAULT), //
				getLong(GpsNmeaTransportService.SERIAL_READINTERVALTIMEOUT_PROPERTY, GpsNmeaTransportService.SERIAL_READINTERVALTIMEOUT_DEFAULT), //
				getLong(GpsNmeaTransportService.SERIAL_WRITETOTALTIMEOUT_PROPERTY, GpsNmeaTransportService.SERIAL_WRITETOTALTIMEOUT_DEFAULT));
	}

	/**
	 * Gets the default tcpip connection.
	 * 
	 * @return TcpipConnectionService The default tcpip connection used by this transport.
	 * @since 1.0
	 */
	public TcpipConnectionService getDefaultTcpipConnection() {
		/* Generated method and should not be changed. */
		return new TcpipConnection(getString(GpsNmeaTransportService.TCPIP_LOCALHOST_PROPERTY, GpsNmeaTransportService.TCPIP_LOCALHOST_DEFAULT), //
				getInt(GpsNmeaTransportService.TCPIP_LOCALPORT_PROPERTY, GpsNmeaTransportService.TCPIP_LOCALPORT_DEFAULT), //
				getString(GpsNmeaTransportService.TCPIP_REMOTEHOST_PROPERTY, GpsNmeaTransportService.TCPIP_REMOTEHOST_DEFAULT), //
				getInt(GpsNmeaTransportService.TCPIP_REMOTEPORT_PROPERTY, GpsNmeaTransportService.TCPIP_REMOTEPORT_DEFAULT), //
				getInt(GpsNmeaTransportService.TCPIP_READTIMEOUT_PROPERTY, GpsNmeaTransportService.TCPIP_READTIMEOUT_DEFAULT), //
				getInt(GpsNmeaTransportService.TCPIP_READSIZE_PROPERTY, GpsNmeaTransportService.TCPIP_READSIZE_DEFAULT), //
				getInt(GpsNmeaTransportService.TCPIP_WRITESIZE_PROPERTY, GpsNmeaTransportService.TCPIP_WRITESIZE_DEFAULT), //
				getInt(GpsNmeaTransportService.TCPIP_LINGER_PROPERTY, GpsNmeaTransportService.TCPIP_LINGER_DEFAULT));
	}

	/**
	 * Sets user-defined variables to use in the test.
	 * <p>User defined properties and default values.
	 * <table>
	 * <tr>
	 * <td>retrytime</td>
	 * <td>RETRY_TIME_DEFAULT</td>
	 * </tr>
	 * <tr>
	 * <td>transmitretries</td>
	 * <td>TRANSMIT_RETRIES_DEFAULT</td>
	 * </tr>
	 * <tr>
	 * <td>noactivitytimeout</td>
	 * <td>NO_ACTIVITY_TIMEOUT_DEFAULT</td>
	 * </tr>
	 * </table>
	 * 
	 * @see org.eclipse.soda.dk.transport.Transport#setup()
	 * @since 1.0
	 */
	public void setup() {
		/* Generated method and should not be changed. */
		super.setup();
		setRetryTime(getLong("gpsnmeatransport.retrytime", getRetryTime())); //$NON-NLS-1$
		setPriority(getInt("gpsnmeatransport.priority", getPriority())); //$NON-NLS-1$
		setNotificationPriority(getInt("gpsnmeatransport.notificationpriority", getNotificationPriority())); //$NON-NLS-1$
		setTransmitRetries(getInt("gpsnmeatransport.transmitretries", getTransmitRetries())); //$NON-NLS-1$
		setNoActivityTimeout(getLong("gpsnmeatransport.noactivitytimeout", getNoActivityTimeout())); //$NON-NLS-1$
	}
}
